# encoding: utf-8
# module System.Windows.Ink calls itself Ink
# from PresentationCore,Version=4.0.0.0,Culture=neutral,PublicKeyToken=31bf3856ad364e35
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class ApplicationGesture(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the available application-specific gesture.

 

 enum ApplicationGesture,values: AllGestures (0),ArrowDown (61497),ArrowLeft (61498),ArrowRight (61499),ArrowUp (61496),Check (61445),ChevronDown (61489),ChevronLeft (61490),ChevronRight (61491),ChevronUp (61488),Circle (61472),Curlicue (61456),DoubleCircle (61473),DoubleCurlicue (61457),DoubleTap (61681),Down (61529),DownLeft (61546),DownLeftLong (61542),DownRight (61547),DownRightLong (61543),DownUp (61537),Exclamation (61604),Left (61530),LeftDown (61549),LeftRight (61538),LeftUp (61548),NoGesture (61440),Right (61531),RightDown (61551),RightLeft (61539),RightUp (61550),ScratchOut (61441),SemicircleLeft (61480),SemicircleRight (61481),Square (61443),Star (61444),Tap (61680),Triangle (61442),Up (61528),UpDown (61536),UpLeft (61544),UpLeftLong (61540),UpRight (61545),UpRightLong (61541)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AllGestures=None
 ArrowDown=None
 ArrowLeft=None
 ArrowRight=None
 ArrowUp=None
 Check=None
 ChevronDown=None
 ChevronLeft=None
 ChevronRight=None
 ChevronUp=None
 Circle=None
 Curlicue=None
 DoubleCircle=None
 DoubleCurlicue=None
 DoubleTap=None
 Down=None
 DownLeft=None
 DownLeftLong=None
 DownRight=None
 DownRightLong=None
 DownUp=None
 Exclamation=None
 Left=None
 LeftDown=None
 LeftRight=None
 LeftUp=None
 NoGesture=None
 Right=None
 RightDown=None
 RightLeft=None
 RightUp=None
 ScratchOut=None
 SemicircleLeft=None
 SemicircleRight=None
 Square=None
 Star=None
 Tap=None
 Triangle=None
 Up=None
 UpDown=None
 UpLeft=None
 UpLeftLong=None
 UpRight=None
 UpRightLong=None
 value__=None


class DrawingAttributeIds(object):
 """ Contains a set of GUIDs that identify the properties in the System.Windows.Ink.DrawingAttributes class. """
 Color=None
 DrawingFlags=None
 IsHighlighter=None
 StylusHeight=None
 StylusTip=None
 StylusTipTransform=None
 StylusWidth=None
 __all__=[
  'Color',
  'DrawingFlags',
  'IsHighlighter',
  'StylusHeight',
  'StylusTip',
  'StylusTipTransform',
  'StylusWidth',
 ]


class DrawingAttributes(object,INotifyPropertyChanged):
 """
 Specifies the appearance of a System.Windows.Ink.Stroke

 

 DrawingAttributes()
 """
 def AddPropertyData(self,propertyDataId,propertyData):
  """
  AddPropertyData(self: DrawingAttributes,propertyDataId: Guid,propertyData: object)

   Adds a custom property to the System.Windows.Ink.DrawingAttributes object.

  

   propertyDataId: The System.Guid to associate with the custom property.

   propertyData: The value of the custom property. propertyData must be of type System.Char,System.Byte,

    System.Int16,System.UInt16,System.Int32,System.UInt32,System.Int64,System.UInt64,

    System.Single,System.Double,System.DateTime,System.Boolean,System.String,System.Decimal or 

    an array of these data types; however it cannot be an array of type System.String.
  """
  pass
 def Clone(self):
  """
  Clone(self: DrawingAttributes) -> DrawingAttributes

  

   Copies the System.Windows.Ink.DrawingAttributes object.

   Returns: A copy of the System.Windows.Ink.DrawingAttributes object.
  """
  pass
 def ContainsPropertyData(self,propertyDataId):
  """
  ContainsPropertyData(self: DrawingAttributes,propertyDataId: Guid) -> bool

  

   Returns a value that indicates whether the specified property data identifier is in the 

    System.Windows.Ink.DrawingAttributes object.

  

  

   propertyDataId: The System.Guid to locate in the System.Windows.Ink.DrawingAttributes object .

   Returns: true if the specified property data identifier is in the System.Windows.Ink.DrawingAttributes 

    object; otherwise,false.
  """
  pass
 def Equals(self,o):
  """
  Equals(self: DrawingAttributes,o: object) -> bool

  

   Determines whether the specified System.Windows.Ink.DrawingAttributes object is equal to the 

    current System.Windows.Ink.DrawingAttributes object.

  

  

   o: The System.Windows.Ink.DrawingAttributes object to compare to the current 

    System.Windows.Ink.DrawingAttributes object.

  

   Returns: true if the objects are equal; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """ GetHashCode(self: DrawingAttributes) -> int """
  pass
 def GetPropertyData(self,propertyDataId):
  """
  GetPropertyData(self: DrawingAttributes,propertyDataId: Guid) -> object

  

   Gets the value of the custom property associated with the specified System.Guid.

  

   propertyDataId: The System.Guid associated with the custom property to get.

   Returns: The value of the custom property associated with the specified System.Guid.
  """
  pass
 def GetPropertyDataIds(self):
  """
  GetPropertyDataIds(self: DrawingAttributes) -> Array[Guid]

  

   Returns the GUIDs of any custom properties associated with the 

    System.Windows.Ink.StrokeCollection.

  

   Returns: An array of type System.Guid that represents the property data identifiers.
  """
  pass
 def OnAttributeChanged(self,*args):
  """
  OnAttributeChanged(self: DrawingAttributes,e: PropertyDataChangedEventArgs)

   Raises the System.Windows.Ink.DrawingAttributes.AttributeChanged event.

  

   e: A System.Windows.Ink.PropertyDataChangedEventArgs that contains the event data.
  """
  pass
 def OnPropertyChanged(self,*args):
  """
  OnPropertyChanged(self: DrawingAttributes,e: PropertyChangedEventArgs)

   Occurs when any System.Windows.Ink.DrawingAttributes property changes.

  

   e: EventArgs
  """
  pass
 def OnPropertyDataChanged(self,*args):
  """
  OnPropertyDataChanged(self: DrawingAttributes,e: PropertyDataChangedEventArgs)

   Raises the System.Windows.Ink.DrawingAttributes.PropertyDataChanged event.

  

   e: A System.Windows.Ink.PropertyDataChangedEventArgs that contains the event data.
  """
  pass
 def RemovePropertyData(self,propertyDataId):
  """
  RemovePropertyData(self: DrawingAttributes,propertyDataId: Guid)

   Removes the custom property associated with the specified System.Guid.

  

   propertyDataId: The System.Guid associated with the custom property to remove.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __ne__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 Color=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the color of a System.Windows.Ink.Stroke.



Get: Color(self: DrawingAttributes) -> Color



Set: Color(self: DrawingAttributes)=value

"""

 FitToCurve=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether Bezier smoothing is used to render the System.Windows.Ink.Stroke.



Get: FitToCurve(self: DrawingAttributes) -> bool



Set: FitToCurve(self: DrawingAttributes)=value

"""

 Height=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the height of the stylus used to draw the System.Windows.Ink.Stroke.



Get: Height(self: DrawingAttributes) -> float



Set: Height(self: DrawingAttributes)=value

"""

 IgnorePressure=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether the thickness of a rendered System.Windows.Ink.Stroke changes according the amount of pressure applied.



Get: IgnorePressure(self: DrawingAttributes) -> bool



Set: IgnorePressure(self: DrawingAttributes)=value

"""

 IsHighlighter=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether the System.Windows.Ink.Stroke looks like a highlighter.



Get: IsHighlighter(self: DrawingAttributes) -> bool



Set: IsHighlighter(self: DrawingAttributes)=value

"""

 StylusTip=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the shape of the stylus used to draw the System.Windows.Ink.Stroke.



Get: StylusTip(self: DrawingAttributes) -> StylusTip



Set: StylusTip(self: DrawingAttributes)=value

"""

 StylusTipTransform=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the System.Windows.Media.Matrix that specifies the transformation to perform on the stylus' tip.



Get: StylusTipTransform(self: DrawingAttributes) -> Matrix



Set: StylusTipTransform(self: DrawingAttributes)=value

"""

 Width=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the width of the stylus used to draw the System.Windows.Ink.Stroke.



Get: Width(self: DrawingAttributes) -> float



Set: Width(self: DrawingAttributes)=value

"""


 AttributeChanged=None
 MaxHeight=162329.46141732301
 MaxWidth=162329.46141732301
 MinHeight=3.77952755905512e-05
 MinWidth=3.77952755905512e-05
 PropertyDataChanged=None


class DrawingAttributesReplacedEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Controls.InkCanvas.DefaultDrawingAttributesReplaced event.

 

 DrawingAttributesReplacedEventArgs(newDrawingAttributes: DrawingAttributes,previousDrawingAttributes: DrawingAttributes)
 """
 @staticmethod
 def __new__(self,newDrawingAttributes,previousDrawingAttributes):
  """ __new__(cls: type,newDrawingAttributes: DrawingAttributes,previousDrawingAttributes: DrawingAttributes) """
  pass
 NewDrawingAttributes=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the new System.Windows.Ink.DrawingAttributes.



Get: NewDrawingAttributes(self: DrawingAttributesReplacedEventArgs) -> DrawingAttributes



"""

 PreviousDrawingAttributes=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the old System.Windows.Ink.DrawingAttributes.



Get: PreviousDrawingAttributes(self: DrawingAttributesReplacedEventArgs) -> DrawingAttributes



"""



class DrawingAttributesReplacedEventHandler(MulticastDelegate,ICloneable,ISerializable):
 """
 Represents the method that handles the System.Windows.Controls.InkCanvas.DefaultDrawingAttributesReplaced event of an System.Windows.Controls.InkCanvas.

 

 DrawingAttributesReplacedEventHandler(object: object,method: IntPtr)
 """
 def BeginInvoke(self,sender,e,callback,object):
  """ BeginInvoke(self: DrawingAttributesReplacedEventHandler,sender: object,e: DrawingAttributesReplacedEventArgs,callback: AsyncCallback,object: object) -> IAsyncResult """
  pass
 def CombineImpl(self,*args):
  """
  CombineImpl(self: MulticastDelegate,follow: Delegate) -> Delegate

  

   Combines this System.Delegate with the specified System.Delegate to form a new delegate.

  

   follow: The delegate to combine with this delegate.

   Returns: A delegate that is the new root of the System.MulticastDelegate invocation list.
  """
  pass
 def DynamicInvokeImpl(self,*args):
  """
  DynamicInvokeImpl(self: Delegate,args: Array[object]) -> object

  

   Dynamically invokes (late-bound) the method represented by the current delegate.

  

   args: An array of objects that are the arguments to pass to the method represented by the current 

    delegate.-or- null,if the method represented by the current delegate does not require 

    arguments.

  

   Returns: The object returned by the method represented by the delegate.
  """
  pass
 def EndInvoke(self,result):
  """ EndInvoke(self: DrawingAttributesReplacedEventHandler,result: IAsyncResult) """
  pass
 def GetMethodImpl(self,*args):
  """
  GetMethodImpl(self: MulticastDelegate) -> MethodInfo

  

   Returns a static method represented by the current System.MulticastDelegate.

   Returns: A static method represented by the current System.MulticastDelegate.
  """
  pass
 def Invoke(self,sender,e):
  """ Invoke(self: DrawingAttributesReplacedEventHandler,sender: object,e: DrawingAttributesReplacedEventArgs) """
  pass
 def RemoveImpl(self,*args):
  """
  RemoveImpl(self: MulticastDelegate,value: Delegate) -> Delegate

  

   Removes an element from the invocation list of this System.MulticastDelegate that is equal to 

    the specified delegate.

  

  

   value: The delegate to search for in the invocation list.

   Returns: If value is found in the invocation list for this instance,then a new System.Delegate without 

    value in its invocation list; otherwise,this instance with its original invocation list.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,object,method):
  """ __new__(cls: type,object: object,method: IntPtr) """
  pass
 def __reduce_ex__(self,*args):
  pass

class StylusShape(object):
 """ Represents the tip of a stylus. """
 Height=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the height of the stylus.



Get: Height(self: StylusShape) -> float



"""

 Rotation=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the angle of the stylus.



Get: Rotation(self: StylusShape) -> float



"""

 Width=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the width of the stylus.



Get: Width(self: StylusShape) -> float



"""



class EllipseStylusShape(StylusShape):
 """
 Represents a stylus tip shaped like an ellipse.

 

 EllipseStylusShape(width: float,height: float)

 EllipseStylusShape(width: float,height: float,rotation: float)
 """
 @staticmethod
 def __new__(self,width,height,rotation=None):
  """
  __new__(cls: type,width: float,height: float)

  __new__(cls: type,width: float,height: float,rotation: float)
  """
  pass

class GestureRecognitionResult(object):
 """ Contains information about an ink gesture. """
 ApplicationGesture=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the recognized ink gesture.



Get: ApplicationGesture(self: GestureRecognitionResult) -> ApplicationGesture



"""

 RecognitionConfidence=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the level of confidence that the System.Windows.Ink.GestureRecognizer has in the recognition of the gesture.



Get: RecognitionConfidence(self: GestureRecognitionResult) -> RecognitionConfidence



"""



class GestureRecognizer(DependencyObject,IDisposable):
 """
 Recognizes ink gestures.

 

 GestureRecognizer()

 GestureRecognizer(enabledApplicationGestures: IEnumerable[ApplicationGesture])
 """
 def Dispose(self):
  """
  Dispose(self: GestureRecognizer)

   Releases all resources used by the System.Windows.Ink.GestureRecognizer.
  """
  pass
 def GetEnabledGestures(self):
  """
  GetEnabledGestures(self: GestureRecognizer) -> ReadOnlyCollection[ApplicationGesture]

  

   Gets the gestures that the System.Windows.Ink.GestureRecognizer recognizes.

   Returns: An array of type System.Windows.Ink.ApplicationGesture that contains gestures the 

    System.Windows.Ink.GestureRecognizer is set to recognize.
  """
  pass
 def OnPropertyChanged(self,*args):
  """
  OnPropertyChanged(self: DependencyObject,e: DependencyPropertyChangedEventArgs)

   Invoked whenever the effective value of any dependency property on this 

    System.Windows.DependencyObject has been updated. The specific dependency property that changed 

    is reported in the event data.

  

  

   e: Event data that will contain the dependency property identifier of interest,the property 

    metadata for the type,and old and new values.
  """
  pass
 def Recognize(self,strokes):
  """
  Recognize(self: GestureRecognizer,strokes: StrokeCollection) -> ReadOnlyCollection[GestureRecognitionResult]

  

   Looks for gestures in the specified System.Windows.Ink.StrokeCollection.

  

   strokes: The System.Windows.Ink.StrokeCollection to search for gestures.

   Returns: An array of type System.Windows.Ink.GestureRecognitionResult that contains application gestures 

    that the System.Windows.Ink.GestureRecognizer recognized.
  """
  pass
 def SetEnabledGestures(self,applicationGestures):
  """ SetEnabledGestures(self: GestureRecognizer,applicationGestures: IEnumerable[ApplicationGesture]) """
  pass
 def ShouldSerializeProperty(self,*args):
  """
  ShouldSerializeProperty(self: DependencyObject,dp: DependencyProperty) -> bool

  

   Returns a value that indicates whether serialization processes should serialize the value for 

    the provided dependency property.

  

  

   dp: The identifier for the dependency property that should be serialized.

   Returns: true if the dependency property that is supplied should be value-serialized; otherwise,false.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,enabledApplicationGestures=None):
  """
  __new__(cls: type)

  __new__(cls: type,enabledApplicationGestures: IEnumerable[ApplicationGesture])
  """
  pass
 IsRecognizerAvailable=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a Boolean that indicates whether the gesture recognizer is available on the user's system.



Get: IsRecognizerAvailable(self: GestureRecognizer) -> bool



"""



class IncrementalHitTester(object):
 """ Dynamically performs hit testing on a System.Windows.Ink.Stroke. """
 def AddPoint(self,point):
  """
  AddPoint(self: IncrementalHitTester,point: Point)

   Adds a System.Windows.Point to the System.Windows.Ink.IncrementalHitTester.

  

   point: The System.Windows.Point to add to the System.Windows.Ink.IncrementalHitTester.
  """
  pass
 def AddPoints(self,*__args):
  """
  AddPoints(self: IncrementalHitTester,stylusPoints: StylusPointCollection)

   Adds the specified System.Windows.Input.StylusPoint objects to the 

    System.Windows.Ink.IncrementalHitTester.

  

  

   stylusPoints: A collection of System.Windows.Input.StylusPoint objects to add to the 

    System.Windows.Ink.IncrementalHitTester.

  

  AddPoints(self: IncrementalHitTester,points: IEnumerable[Point])
  """
  pass
 def AddPointsCore(self,*args):
  """ AddPointsCore(self: IncrementalHitTester,points: IEnumerable[Point]) """
  pass
 def EndHitTesting(self):
  """
  EndHitTesting(self: IncrementalHitTester)

   Releases resources used by the System.Windows.Ink.IncrementalHitTester.
  """
  pass
 IsValid=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets whether the System.Windows.Ink.IncrementalHitTester is hit testing.



Get: IsValid(self: IncrementalHitTester) -> bool



"""



class IncrementalLassoHitTester(IncrementalHitTester):
 """ Dynamically hit tests a System.Windows.Ink.Stroke with a lasso. """
 def OnSelectionChanged(self,*args):
  """
  OnSelectionChanged(self: IncrementalLassoHitTester,eventArgs: LassoSelectionChangedEventArgs)

   Raises the System.Windows.Ink.IncrementalLassoHitTester.SelectionChanged event.

  

   eventArgs: Event data.
  """
  pass
 SelectionChanged=None


class IncrementalStrokeHitTester(IncrementalHitTester):
 """ Dynamically hit tests a stroke with an eraser path. """
 def OnStrokeHit(self,*args):
  """
  OnStrokeHit(self: IncrementalStrokeHitTester,eventArgs: StrokeHitEventArgs)

   Raises the System.Windows.Ink.IncrementalStrokeHitTester.StrokeHit event.

  

   eventArgs: Event data.
  """
  pass
 StrokeHit=None


class LassoSelectionChangedEventArgs(EventArgs):
 """ Provides data for the System.Windows.Ink.IncrementalLassoHitTester.SelectionChanged event. """
 DeselectedStrokes=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the strokes that have been removed from lasso path since the last time the System.Windows.Ink.IncrementalLassoHitTester.SelectionChanged event was raised.



Get: DeselectedStrokes(self: LassoSelectionChangedEventArgs) -> StrokeCollection



"""

 SelectedStrokes=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the strokes that have been surrounded by the lasso path since the last time the System.Windows.Ink.IncrementalLassoHitTester.SelectionChanged event was raised.



Get: SelectedStrokes(self: LassoSelectionChangedEventArgs) -> StrokeCollection



"""



class LassoSelectionChangedEventHandler(MulticastDelegate,ICloneable,ISerializable):
 """
 Represents the method that handles the System.Windows.Ink.IncrementalLassoHitTester.SelectionChanged event of a System.Windows.Ink.IncrementalLassoHitTester.

 

 LassoSelectionChangedEventHandler(object: object,method: IntPtr)
 """
 def BeginInvoke(self,sender,e,callback,object):
  """ BeginInvoke(self: LassoSelectionChangedEventHandler,sender: object,e: LassoSelectionChangedEventArgs,callback: AsyncCallback,object: object) -> IAsyncResult """
  pass
 def CombineImpl(self,*args):
  """
  CombineImpl(self: MulticastDelegate,follow: Delegate) -> Delegate

  

   Combines this System.Delegate with the specified System.Delegate to form a new delegate.

  

   follow: The delegate to combine with this delegate.

   Returns: A delegate that is the new root of the System.MulticastDelegate invocation list.
  """
  pass
 def DynamicInvokeImpl(self,*args):
  """
  DynamicInvokeImpl(self: Delegate,args: Array[object]) -> object

  

   Dynamically invokes (late-bound) the method represented by the current delegate.

  

   args: An array of objects that are the arguments to pass to the method represented by the current 

    delegate.-or- null,if the method represented by the current delegate does not require 

    arguments.

  

   Returns: The object returned by the method represented by the delegate.
  """
  pass
 def EndInvoke(self,result):
  """ EndInvoke(self: LassoSelectionChangedEventHandler,result: IAsyncResult) """
  pass
 def GetMethodImpl(self,*args):
  """
  GetMethodImpl(self: MulticastDelegate) -> MethodInfo

  

   Returns a static method represented by the current System.MulticastDelegate.

   Returns: A static method represented by the current System.MulticastDelegate.
  """
  pass
 def Invoke(self,sender,e):
  """ Invoke(self: LassoSelectionChangedEventHandler,sender: object,e: LassoSelectionChangedEventArgs) """
  pass
 def RemoveImpl(self,*args):
  """
  RemoveImpl(self: MulticastDelegate,value: Delegate) -> Delegate

  

   Removes an element from the invocation list of this System.MulticastDelegate that is equal to 

    the specified delegate.

  

  

   value: The delegate to search for in the invocation list.

   Returns: If value is found in the invocation list for this instance,then a new System.Delegate without 

    value in its invocation list; otherwise,this instance with its original invocation list.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,object,method):
  """ __new__(cls: type,object: object,method: IntPtr) """
  pass
 def __reduce_ex__(self,*args):
  pass

class PropertyDataChangedEventArgs(EventArgs):
 """
 Provides data for the PropertyDataChanged event.

 

 PropertyDataChangedEventArgs(propertyGuid: Guid,newValue: object,previousValue: object)
 """
 @staticmethod
 def __new__(self,propertyGuid,newValue,previousValue):
  """ __new__(cls: type,propertyGuid: Guid,newValue: object,previousValue: object) """
  pass
 NewValue=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the new custom property object.



Get: NewValue(self: PropertyDataChangedEventArgs) -> object



"""

 PreviousValue=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the previous custom property object.



Get: PreviousValue(self: PropertyDataChangedEventArgs) -> object



"""

 PropertyGuid=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Guid of the custom property which changed.



Get: PropertyGuid(self: PropertyDataChangedEventArgs) -> Guid



"""



class PropertyDataChangedEventHandler(MulticastDelegate,ICloneable,ISerializable):
 """
 Represents the method that handles the PropertyDataChanged event.

 

 PropertyDataChangedEventHandler(object: object,method: IntPtr)
 """
 def BeginInvoke(self,sender,e,callback,object):
  """ BeginInvoke(self: PropertyDataChangedEventHandler,sender: object,e: PropertyDataChangedEventArgs,callback: AsyncCallback,object: object) -> IAsyncResult """
  pass
 def CombineImpl(self,*args):
  """
  CombineImpl(self: MulticastDelegate,follow: Delegate) -> Delegate

  

   Combines this System.Delegate with the specified System.Delegate to form a new delegate.

  

   follow: The delegate to combine with this delegate.

   Returns: A delegate that is the new root of the System.MulticastDelegate invocation list.
  """
  pass
 def DynamicInvokeImpl(self,*args):
  """
  DynamicInvokeImpl(self: Delegate,args: Array[object]) -> object

  

   Dynamically invokes (late-bound) the method represented by the current delegate.

  

   args: An array of objects that are the arguments to pass to the method represented by the current 

    delegate.-or- null,if the method represented by the current delegate does not require 

    arguments.

  

   Returns: The object returned by the method represented by the delegate.
  """
  pass
 def EndInvoke(self,result):
  """ EndInvoke(self: PropertyDataChangedEventHandler,result: IAsyncResult) """
  pass
 def GetMethodImpl(self,*args):
  """
  GetMethodImpl(self: MulticastDelegate) -> MethodInfo

  

   Returns a static method represented by the current System.MulticastDelegate.

   Returns: A static method represented by the current System.MulticastDelegate.
  """
  pass
 def Invoke(self,sender,e):
  """ Invoke(self: PropertyDataChangedEventHandler,sender: object,e: PropertyDataChangedEventArgs) """
  pass
 def RemoveImpl(self,*args):
  """
  RemoveImpl(self: MulticastDelegate,value: Delegate) -> Delegate

  

   Removes an element from the invocation list of this System.MulticastDelegate that is equal to 

    the specified delegate.

  

  

   value: The delegate to search for in the invocation list.

   Returns: If value is found in the invocation list for this instance,then a new System.Delegate without 

    value in its invocation list; otherwise,this instance with its original invocation list.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,object,method):
  """ __new__(cls: type,object: object,method: IntPtr) """
  pass
 def __reduce_ex__(self,*args):
  pass

class RecognitionConfidence(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the confidence level that the System.Windows.Ink.GestureRecognizer determines for a particular ink gesture.

 

 enum RecognitionConfidence,values: Intermediate (1),Poor (2),Strong (0)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Intermediate=None
 Poor=None
 Strong=None
 value__=None


class RectangleStylusShape(StylusShape):
 """
 Represents a rectangular stylus tip.

 

 RectangleStylusShape(width: float,height: float)

 RectangleStylusShape(width: float,height: float,rotation: float)
 """
 @staticmethod
 def __new__(self,width,height,rotation=None):
  """
  __new__(cls: type,width: float,height: float)

  __new__(cls: type,width: float,height: float,rotation: float)
  """
  pass

class Stroke(object,INotifyPropertyChanged):
 """
 Represents a single ink stroke.

 

 Stroke(stylusPoints: StylusPointCollection)

 Stroke(stylusPoints: StylusPointCollection,drawingAttributes: DrawingAttributes)
 """
 def AddPropertyData(self,propertyDataId,propertyData):
  """
  AddPropertyData(self: Stroke,propertyDataId: Guid,propertyData: object)

   Adds a custom property to the System.Windows.Ink.Stroke object.

  

   propertyDataId: The unique identifier for the property.

   propertyData: The value of the custom property. propertyData must be of type System.Char,

    System.Byte,System.Int16,,System.UInt16,System.Int32,System.UInt32,System.Int64,

    System.UInt64,System.Single,System.Double,System.DateTime,System.Boolean,System.String,

    System.Decimal  or an array of these data types,except System.String,which is not allowed.
  """
  pass
 def Clone(self):
  """
  Clone(self: Stroke) -> Stroke

  

   Returns a deep copy of the existing System.Windows.Ink.Stroke object.

   Returns: The new System.Windows.Ink.Stroke object.
  """
  pass
 def ContainsPropertyData(self,propertyDataId):
  """
  ContainsPropertyData(self: Stroke,propertyDataId: Guid) -> bool

  

   Returns a value that indicates whether the System.Windows.Ink.Stroke object contains the 

    specified custom property.

  

  

   propertyDataId: The unique identifier for the property.

   Returns: Returns true if the custom property exists; otherwise,returns false.
  """
  pass
 def Draw(self,*__args):
  """
  Draw(self: Stroke,drawingContext: DrawingContext,drawingAttributes: DrawingAttributes)

   Renders the System.Windows.Ink.Stroke object based upon the specified 

    System.Windows.Media.DrawingContext and Microsoft.Ink.DrawingAttributes.

  

  

   drawingContext: The System.Windows.Media.DrawingContext object onto which the stroke will be rendered.

   drawingAttributes: The Microsoft.Ink.DrawingAttributes object defining the attributes of the stroke that is drawn.

  Draw(self: Stroke,context: DrawingContext)

   Renders the System.Windows.Ink.Stroke object based upon the specified 

    System.Windows.Media.DrawingContext.
  """
  pass
 def DrawCore(self,*args):
  """
  DrawCore(self: Stroke,drawingContext: DrawingContext,drawingAttributes: DrawingAttributes)

   Renders the System.Windows.Ink.Stroke on the specified System.Windows.Media.DrawingContext using 

    the specified Microsoft.Ink.DrawingAttributes.

  

  

   drawingContext: The System.Windows.Media.DrawingContext object onto which the stroke will be rendered.

   drawingAttributes: The Microsoft.Ink.DrawingAttributes object defining the attributes of the stroke that is drawn.
  """
  pass
 def GetBezierStylusPoints(self):
  """
  GetBezierStylusPoints(self: Stroke) -> StylusPointCollection

  

   Returns the stylus points the System.Windows.Ink.Stroke uses when 

    System.Windows.Ink.DrawingAttributes.FitToCurve is true.

  

   Returns: A System.Windows.Input.StylusPointCollection that contains the stylus points along the spine of 

    a System.Windows.Ink.Stroke when System.Windows.Ink.DrawingAttributes.FitToCurve is true
  """
  pass
 def GetBounds(self):
  """
  GetBounds(self: Stroke) -> Rect

  

   Retrieves the bounding box for the System.Windows.Ink.Stroke object.

   Returns: A System.Windows.Rect structure defining the bounding box for the System.Windows.Ink.Stroke 

    object.
  """
  pass
 def GetClipResult(self,*__args):
  """
  GetClipResult(self: Stroke,lassoPoints: IEnumerable[Point]) -> StrokeCollection

  GetClipResult(self: Stroke,bounds: Rect) -> StrokeCollection

  

   Returns segments of the current System.Windows.Ink.Stroke that are within the specified 

    rectangle.

  

  

   bounds: A System.Windows.Rect that specifies the area to clip.

   Returns: A System.Windows.Ink.StrokeCollection that contains copies of the segments of the current 

    System.Windows.Ink.Stroke that are within the bounds of bounds.
  """
  pass
 def GetEraseResult(self,*__args):
  """
  GetEraseResult(self: Stroke,eraserPath: IEnumerable[Point],eraserShape: StylusShape) -> StrokeCollection

  GetEraseResult(self: Stroke,lassoPoints: IEnumerable[Point]) -> StrokeCollection

  GetEraseResult(self: Stroke,bounds: Rect) -> StrokeCollection

  

   Returns segments of the current System.Windows.Ink.Stroke that are outside the specified 

    rectangle.

  

  

   bounds: A System.Windows.Rect that specifies the area to erase.

   Returns: A System.Windows.Ink.StrokeCollection that contains the segments of the current 

    System.Windows.Ink.Stroke that are outside the bounds of the specified System.Windows.Rect.
  """
  pass
 def GetGeometry(self,drawingAttributes=None):
  """
  GetGeometry(self: Stroke,drawingAttributes: DrawingAttributes) -> Geometry

  

   Gets the System.Windows.Media.Geometry of the current System.Windows.Ink.Stroke using the 

    specified System.Windows.Ink.DrawingAttributes.

  

  

   drawingAttributes: The System.Windows.Ink.DrawingAttributes that determines the System.Windows.Media.Geometry of 

    the System.Windows.Ink.Stroke.

  

   Returns: A System.Windows.Media.Geometry that represents the System.Windows.Ink.Stroke.

  GetGeometry(self: Stroke) -> Geometry

  

   Gets the System.Windows.Media.Geometry of the current System.Windows.Ink.Stroke.

   Returns: A System.Windows.Media.Geometry that represents the System.Windows.Ink.Stroke.
  """
  pass
 def GetPropertyData(self,propertyDataId):
  """
  GetPropertyData(self: Stroke,propertyDataId: Guid) -> object

  

   Retrieves the property data for the specified GUID.

  

   propertyDataId: The unique identifier for the property.

   Returns: An object containing the property data.
  """
  pass
 def GetPropertyDataIds(self):
  """
  GetPropertyDataIds(self: Stroke) -> Array[Guid]

  

   Retrieves the GUIDs of any custom properties associated with the System.Windows.Ink.Stroke 

    object.

  

   Returns: An array of System.Guid objects.
  """
  pass
 def HitTest(self,*__args):
  """
  HitTest(self: Stroke,lassoPoints: IEnumerable[Point],percentageWithinLasso: int) -> bool

  HitTest(self: Stroke,path: IEnumerable[Point],stylusShape: StylusShape) -> bool

  HitTest(self: Stroke,bounds: Rect,percentageWithinBounds: int) -> bool

  

   Returns a value that indicates whether the System.Windows.Ink.Stroke is within the bounds of the 

    specified rectangle.

  

  

   percentageWithinBounds: The percentage of the length of the System.Windows.Ink.Stroke,that must be in 

    percentageWithinBounds for the System.Windows.Ink.Stroke to be considered hit..

  

   Returns: true if the current stroke is within the bounds of bounds; otherwise false.

  HitTest(self: Stroke,point: Point) -> bool

  

   Returns a value that indicates whether current System.Windows.Ink.Stroke intersects the 

    specified point.

  

  

   point: The System.Windows.Point to hit test.

   Returns: true if point intersects the current stroke; otherwise,false.

  HitTest(self: Stroke,point: Point,diameter: float) -> bool

  

   Returns a value that indicates whether current System.Windows.Ink.Stroke intersects the 

    specified area.

  

  

   point: The System.Windows.Point that defines the center of the area to hit test.

   diameter: The diameter of the area to hit test.

   Returns: true if the specified area intersects the current stroke; otherwise,false.
  """
  pass
 def OnDrawingAttributesChanged(self,*args):
  """
  OnDrawingAttributesChanged(self: Stroke,e: PropertyDataChangedEventArgs)

   Allows derived classes to modify the default behavior of the 

    System.Windows.Ink.Stroke.DrawingAttributesChanged event.

  

  

   e: The System.Windows.Ink.PropertyDataChangedEventArgs object that contains the event data.
  """
  pass
 def OnDrawingAttributesReplaced(self,*args):
  """
  OnDrawingAttributesReplaced(self: Stroke,e: DrawingAttributesReplacedEventArgs)

   Allows derived classes to modify the default behavior of the 

    System.Windows.Ink.Stroke.DrawingAttributesReplaced event.

  

  

   e: The System.Windows.Ink.DrawingAttributesReplacedEventArgs object that contains the event data.
  """
  pass
 def OnInvalidated(self,*args):
  """
  OnInvalidated(self: Stroke,e: EventArgs)

   Raises the System.Windows.Ink.Stroke.Invalidated event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnPropertyChanged(self,*args):
  """
  OnPropertyChanged(self: Stroke,e: PropertyChangedEventArgs)

   Occurs when any System.Windows.Ink.Stroke property changes.
  """
  pass
 def OnPropertyDataChanged(self,*args):
  """
  OnPropertyDataChanged(self: Stroke,e: PropertyDataChangedEventArgs)

   Allows derived classes to modify the default behavior of the 

    System.Windows.Ink.Stroke.PropertyDataChanged event.

  

  

   e: The System.Windows.Ink.PropertyDataChangedEventArgs object that contains the event data.
  """
  pass
 def OnStylusPointsChanged(self,*args):
  """
  OnStylusPointsChanged(self: Stroke,e: EventArgs)

   Raises the System.Windows.Ink.Stroke.StylusPointsChanged event.

  

   e: A System.EventArgs that contains the event data.
  """
  pass
 def OnStylusPointsReplaced(self,*args):
  """
  OnStylusPointsReplaced(self: Stroke,e: StylusPointsReplacedEventArgs)

   Raises the System.Windows.Ink.Stroke.StylusPointsReplaced event.

  

   e: A System.Windows.Ink.StylusPointsReplacedEventArgs that contains the event data.
  """
  pass
 def RemovePropertyData(self,propertyDataId):
  """
  RemovePropertyData(self: Stroke,propertyDataId: Guid)

   Deletes a custom property from the System.Windows.Ink.Stroke object.

  

   propertyDataId: The unique identifier for the property.
  """
  pass
 def Transform(self,transformMatrix,applyToStylusTip):
  """
  Transform(self: Stroke,transformMatrix: Matrix,applyToStylusTip: bool)

   Performs a transformation based upon the specified System.Windows.Media.Matrix object.

  

   transformMatrix: The System.Windows.Media.Matrix object defining the transformation.

   applyToStylusTip: true to apply the transformation to the tip of the stylus; otherwise,false.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,stylusPoints,drawingAttributes=None):
  """
  __new__(cls: type,stylusPoints: StylusPointCollection)

  __new__(cls: type,stylusPoints: StylusPointCollection,drawingAttributes: DrawingAttributes)
  """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 DrawingAttributes=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the System.Windows.Ink.DrawingAttributes for the System.Windows.Ink.Stroke object.



Get: DrawingAttributes(self: Stroke) -> DrawingAttributes



Set: DrawingAttributes(self: Stroke)=value

"""

 StylusPoints=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Returns the stylus points of the System.Windows.Ink.Stroke.



Get: StylusPoints(self: Stroke) -> StylusPointCollection



Set: StylusPoints(self: Stroke)=value

"""


 DrawingAttributesChanged=None
 DrawingAttributesReplaced=None
 Invalidated=None
 PropertyDataChanged=None
 StylusPointsChanged=None
 StylusPointsReplaced=None


class StrokeCollection(Collection[Stroke],IList[Stroke],ICollection[Stroke],IEnumerable[Stroke],IEnumerable,IList,ICollection,IReadOnlyList[Stroke],IReadOnlyCollection[Stroke],INotifyPropertyChanged,INotifyCollectionChanged):
 """
 Represents a collection of System.Windows.Ink.Stroke objects.

 

 StrokeCollection()

 StrokeCollection(strokes: IEnumerable[Stroke])

 StrokeCollection(stream: Stream)
 """
 def Add(self,*__args):
  """
  Add(self: StrokeCollection,strokes: StrokeCollection)

   Adds the specified strokes to the System.Windows.Ink.StrokeCollection.

  

   strokes: The System.Windows.Ink.StrokeCollection to add to the collection.
  """
  pass
 def AddPropertyData(self,propertyDataId,propertyData):
  """
  AddPropertyData(self: StrokeCollection,propertyDataId: Guid,propertyData: object)

   Adds a custom property to the System.Windows.Ink.StrokeCollection.

  

   propertyDataId: The System.Guid to associate with the custom property.

   propertyData: The value of the custom property. propertyData must be of type System.Char,

    System.Byte,System.Int16,,System.UInt16,System.Int32,System.UInt32,System.Int64,

    System.UInt64,System.Single,System.Double,System.DateTime,System.Boolean,System.String,

    System.Decimal or an array of these data types,except System.String,which is not allowed.
  """
  pass
 def ClearItems(self,*args):
  """
  ClearItems(self: StrokeCollection)

   Clears all strokes from the System.Windows.Ink.StrokeCollection.
  """
  pass
 def Clip(self,*__args):
  """
  Clip(self: StrokeCollection,bounds: Rect)

   Replaces all strokes that are clipped by the specified rectangle with new strokes that do not 

    extend beyond the specified rectangle.

  

  

   bounds: A System.Windows.Rect that specifies the area to be clipped.

  Clip(self: StrokeCollection,lassoPoints: IEnumerable[Point])
  """
  pass
 def Clone(self):
  """
  Clone(self: StrokeCollection) -> StrokeCollection

  

   Copies the System.Windows.Ink.StrokeCollection.

   Returns: A copy of the System.Windows.Ink.StrokeCollection.
  """
  pass
 def ContainsPropertyData(self,propertyDataId):
  """
  ContainsPropertyData(self: StrokeCollection,propertyDataId: Guid) -> bool

  

   Returns whether the specified custom property identifier is in the 

    System.Windows.Ink.StrokeCollection.

  

  

   propertyDataId: The System.Guid to locate in the System.Windows.Ink.StrokeCollection.

   Returns: true if the specified custom property identifier is in the System.Windows.Ink.StrokeCollection; 

    otherwise,false.
  """
  pass
 def Draw(self,context):
  """
  Draw(self: StrokeCollection,context: DrawingContext)

   Draws the strokes in the System.Windows.Ink.StrokeCollection.

  

   context: The System.Windows.Media.DrawingContext on which to draw the System.Windows.Ink.StrokeCollection.
  """
  pass
 def Erase(self,*__args):
  """
  Erase(self: StrokeCollection,eraserPath: IEnumerable[Point],eraserShape: StylusShape)Erase(self: StrokeCollection,bounds: Rect)

   Replaces all strokes that are clipped by the specified rectangle with new strokes that do not 

    enter the bounds of the specified rectangle.

  

  Erase(self: StrokeCollection,lassoPoints: IEnumerable[Point])
  """
  pass
 def GetBounds(self):
  """
  GetBounds(self: StrokeCollection) -> Rect

  

   Returns the bounds of the strokes in the collection.

   Returns: A System.Windows.Rect that contains the bounds of the strokes in the 

    System.Windows.Ink.StrokeCollection.
  """
  pass
 def GetIncrementalLassoHitTester(self,percentageWithinLasso):
  """
  GetIncrementalLassoHitTester(self: StrokeCollection,percentageWithinLasso: int) -> IncrementalLassoHitTester

  

   Creates an System.Windows.Ink.IncrementalLassoHitTester that hit tests the 

    System.Windows.Ink.StrokeCollection with a lasso (freehand) path.

  

  

   percentageWithinLasso: The minimum percentage of each System.Windows.Ink.Stroke that must be contained within the lasso 

    for it to be considered hit.

  

   Returns: An System.Windows.Ink.IncrementalLassoHitTester that hit tests the 

    System.Windows.Ink.StrokeCollection.
  """
  pass
 def GetIncrementalStrokeHitTester(self,eraserShape):
  """
  GetIncrementalStrokeHitTester(self: StrokeCollection,eraserShape: StylusShape) -> IncrementalStrokeHitTester

  

   Creates an System.Windows.Ink.IncrementalStrokeHitTester that hit tests the 

    System.Windows.Ink.StrokeCollection with an erasing path.

  

  

   eraserShape: A System.Windows.Ink.StylusShape that specifies the tip of the stylus.

   Returns: An System.Windows.Ink.IncrementalStrokeHitTester that hit tests the 

    System.Windows.Ink.StrokeCollection.
  """
  pass
 def GetPropertyData(self,propertyDataId):
  """
  GetPropertyData(self: StrokeCollection,propertyDataId: Guid) -> object

  

   Returns the value of the custom property associated with the specified System.Guid.

  

   propertyDataId: The System.Guid associated with the custom property to get.

   Returns: The value of the custom property associated with the specified System.Guid.
  """
  pass
 def GetPropertyDataIds(self):
  """
  GetPropertyDataIds(self: StrokeCollection) -> Array[Guid]

  

   Returns the GUIDs of any custom properties associated with the 

    System.Windows.Ink.StrokeCollection.

  

   Returns: An array of type System.Guid that represent the custom property identifiers.
  """
  pass
 def HitTest(self,*__args):
  """
  HitTest(self: StrokeCollection,bounds: Rect,percentageWithinBounds: int) -> StrokeCollection

  

   Returns a collection of strokes that have at least the specified percentage of length within the 

    specified rectangle.

  

  

   bounds: A System.Windows.Rect that specifies the bounds to be hit tested.

   percentageWithinBounds: The minimum required length of a Stroke that must exist within bounds for it to be considered 

    hit.

  

   Returns: A System.Windows.Ink.StrokeCollection that has strokes with at least the specified percentage 

    within the System.Windows.Rect.

  

  HitTest(self: StrokeCollection,path: IEnumerable[Point],stylusShape: StylusShape) -> StrokeCollection

  HitTest(self: StrokeCollection,lassoPoints: IEnumerable[Point],percentageWithinLasso: int) -> StrokeCollection

  HitTest(self: StrokeCollection,point: Point) -> StrokeCollection

  

   Returns a collection of strokes that intersect the specified point.

  

   point: The point to hit test.

   Returns: A collection of System.Windows.Ink.Stroke objects that intersect the specified point.

  HitTest(self: StrokeCollection,point: Point,diameter: float) -> StrokeCollection

  

   Returns a collection of strokes that intersect the specified area.

  

   point: The System.Windows.Point to hit test.

   diameter: The size of the area around the System.Windows.Point to hit test.

   Returns: A collection of System.Windows.Ink.Stroke objects that intersect the specified point.
  """
  pass
 def IndexOf(self,*__args):
  """
  IndexOf(self: StrokeCollection,stroke: Stroke) -> int

  

   Returns the index of the specified System.Windows.Ink.Stroke in the 

    System.Windows.Ink.StrokeCollection.

  

  

   stroke: The stroke whose position is required.

   Returns: The index of the stroke.
  """
  pass
 def InsertItem(self,*args):
  """
  InsertItem(self: StrokeCollection,index: int,stroke: Stroke)

   Inserts a stroke into the System.Windows.Ink.StrokeCollection at the specified index.
  """
  pass
 def OnPropertyChanged(self,*args):
  """
  OnPropertyChanged(self: StrokeCollection,e: PropertyChangedEventArgs)

   Occurs when any System.Windows.Ink.StrokeCollection property changes.

  

   e: Event data.
  """
  pass
 def OnPropertyDataChanged(self,*args):
  """
  OnPropertyDataChanged(self: StrokeCollection,e: PropertyDataChangedEventArgs)

   Raises the System.Windows.Ink.StrokeCollection.PropertyDataChanged event.
  """
  pass
 def OnStrokesChanged(self,*args):
  """
  OnStrokesChanged(self: StrokeCollection,e: StrokeCollectionChangedEventArgs)

   Raises the System.Windows.Ink.StrokeCollection.StrokesChanged event.

  

   e: A System.Windows.Ink.StrokeCollectionChangedEventArgs that contains the event data.
  """
  pass
 def Remove(self,*__args):
  """
  Remove(self: StrokeCollection,strokes: StrokeCollection)

   Removes the specified strokes from the collection.
  """
  pass
 def RemoveItem(self,*args):
  """
  RemoveItem(self: StrokeCollection,index: int)

   Removes the stroke at the specified index from the System.Windows.Ink.StrokeCollection.

  

   index: The specified index.
  """
  pass
 def RemovePropertyData(self,propertyDataId):
  """
  RemovePropertyData(self: StrokeCollection,propertyDataId: Guid)

   Removes the custom property associated with the specified System.Guid.

  

   propertyDataId: The System.Guid associated with the custom property to remove.
  """
  pass
 def Replace(self,*__args):
  """
  Replace(self: StrokeCollection,strokesToReplace: StrokeCollection,strokesToReplaceWith: StrokeCollection)

   Replaces the specified System.Windows.Ink.StrokeCollection with a new 

    System.Windows.Ink.StrokeCollection.

  

  

   strokesToReplace: The destination System.Windows.Ink.StrokeCollection.

   strokesToReplaceWith: The source System.Windows.Ink.StrokeCollection.

  Replace(self: StrokeCollection,strokeToReplace: Stroke,strokesToReplaceWith: StrokeCollection)

   Replaces the specified System.Windows.Ink.Stroke with the specified 

    System.Windows.Ink.StrokeCollection.

  

  

   strokeToReplace: The System.Windows.Ink.Stroke to replace.

   strokesToReplaceWith: The source System.Windows.Ink.StrokeCollection.
  """
  pass
 def Save(self,stream,compress=None):
  """
  Save(self: StrokeCollection,stream: Stream)

   Saves the System.Windows.Ink.StrokeCollection to the specified System.IO.Stream.

  

   stream: The System.IO.Stream to which to save the System.Windows.Ink.StrokeCollection.

  Save(self: StrokeCollection,stream: Stream,compress: bool)

   Saves the System.Windows.Ink.StrokeCollection to the specified System.IO.Stream and compresses 

    it,when specified.

  

  

   stream: The System.IO.Stream to which to save the System.Windows.Ink.StrokeCollection.

   compress: true to compress the System.Windows.Ink.StrokeCollection; otherwise,false.
  """
  pass
 def SetItem(self,*args):
  """
  SetItem(self: StrokeCollection,index: int,stroke: Stroke)

   Replaces the stroke at the specified index.
  """
  pass
 def Transform(self,transformMatrix,applyToStylusTip):
  """
  Transform(self: StrokeCollection,transformMatrix: Matrix,applyToStylusTip: bool)

   Modifies each of the System.Windows.Ink.Stroke.StylusPoints and optionally the 

    System.Windows.Ink.DrawingAttributes.StylusTipTransform for each stroke in the 

    System.Windows.Ink.StrokeCollection according to the specified System.Windows.Media.Matrix.

  

  

   transformMatrix: A System.Windows.Media.Matrix which specifies the transformation to perform on the 

    System.Windows.Ink.StrokeCollection.

  

   applyToStylusTip: true to apply the transformation to the tip of the stylus; otherwise,false.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,strokes: IEnumerable[Stroke])

  __new__(cls: type,stream: Stream)
  """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 Items=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.Collections.Generic.IList wrapper around the System.Collections.ObjectModel.Collection.



"""


 InkSerializedFormat='Ink Serialized Format'
 PropertyDataChanged=None
 StrokesChanged=None


class StrokeCollectionChangedEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Ink.StrokeCollection.StrokesChanged event.

 

 StrokeCollectionChangedEventArgs(added: StrokeCollection,removed: StrokeCollection)
 """
 @staticmethod
 def __new__(self,added,removed):
  """ __new__(cls: type,added: StrokeCollection,removed: StrokeCollection) """
  pass
 Added=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the strokes that have been added to the System.Windows.Ink.StrokeCollection.



Get: Added(self: StrokeCollectionChangedEventArgs) -> StrokeCollection



"""

 Removed=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the strokes that have been removed from the System.Windows.Ink.StrokeCollection.



Get: Removed(self: StrokeCollectionChangedEventArgs) -> StrokeCollection



"""



class StrokeCollectionChangedEventHandler(MulticastDelegate,ICloneable,ISerializable):
 """
 Represents the method that handles the System.Windows.Ink.StrokeCollection.StrokesChanged event of a System.Windows.Ink.StrokeCollection.

 

 StrokeCollectionChangedEventHandler(object: object,method: IntPtr)
 """
 def BeginInvoke(self,sender,e,callback,object):
  """ BeginInvoke(self: StrokeCollectionChangedEventHandler,sender: object,e: StrokeCollectionChangedEventArgs,callback: AsyncCallback,object: object) -> IAsyncResult """
  pass
 def CombineImpl(self,*args):
  """
  CombineImpl(self: MulticastDelegate,follow: Delegate) -> Delegate

  

   Combines this System.Delegate with the specified System.Delegate to form a new delegate.

  

   follow: The delegate to combine with this delegate.

   Returns: A delegate that is the new root of the System.MulticastDelegate invocation list.
  """
  pass
 def DynamicInvokeImpl(self,*args):
  """
  DynamicInvokeImpl(self: Delegate,args: Array[object]) -> object

  

   Dynamically invokes (late-bound) the method represented by the current delegate.

  

   args: An array of objects that are the arguments to pass to the method represented by the current 

    delegate.-or- null,if the method represented by the current delegate does not require 

    arguments.

  

   Returns: The object returned by the method represented by the delegate.
  """
  pass
 def EndInvoke(self,result):
  """ EndInvoke(self: StrokeCollectionChangedEventHandler,result: IAsyncResult) """
  pass
 def GetMethodImpl(self,*args):
  """
  GetMethodImpl(self: MulticastDelegate) -> MethodInfo

  

   Returns a static method represented by the current System.MulticastDelegate.

   Returns: A static method represented by the current System.MulticastDelegate.
  """
  pass
 def Invoke(self,sender,e):
  """ Invoke(self: StrokeCollectionChangedEventHandler,sender: object,e: StrokeCollectionChangedEventArgs) """
  pass
 def RemoveImpl(self,*args):
  """
  RemoveImpl(self: MulticastDelegate,value: Delegate) -> Delegate

  

   Removes an element from the invocation list of this System.MulticastDelegate that is equal to 

    the specified delegate.

  

  

   value: The delegate to search for in the invocation list.

   Returns: If value is found in the invocation list for this instance,then a new System.Delegate without 

    value in its invocation list; otherwise,this instance with its original invocation list.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,object,method):
  """ __new__(cls: type,object: object,method: IntPtr) """
  pass
 def __reduce_ex__(self,*args):
  pass

class StrokeHitEventArgs(EventArgs):
 """ Represents the method that will handle the System.Windows.Ink.IncrementalStrokeHitTester.StrokeHit event of a System.Windows.Ink.IncrementalStrokeHitTester. """
 def GetPointEraseResults(self):
  """
  GetPointEraseResults(self: StrokeHitEventArgs) -> StrokeCollection

  

   Returns the strokes that are a result of the eraser path erasing a stroke.

   Returns: A System.Windows.Ink.StrokeCollection that contains the strokes that are created after the 

    eraser path erases part of System.Windows.Ink.StrokeHitEventArgs.HitStroke.
  """
  pass
 HitStroke=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Ink.Stroke that is intersected by the eraser path.



Get: HitStroke(self: StrokeHitEventArgs) -> Stroke



"""



class StrokeHitEventHandler(MulticastDelegate,ICloneable,ISerializable):
 """
 Represents the method that will handle the System.Windows.Ink.IncrementalStrokeHitTester.StrokeHit event of a System.Windows.Ink.IncrementalStrokeHitTester.

 

 StrokeHitEventHandler(object: object,method: IntPtr)
 """
 def BeginInvoke(self,sender,e,callback,object):
  """ BeginInvoke(self: StrokeHitEventHandler,sender: object,e: StrokeHitEventArgs,callback: AsyncCallback,object: object) -> IAsyncResult """
  pass
 def CombineImpl(self,*args):
  """
  CombineImpl(self: MulticastDelegate,follow: Delegate) -> Delegate

  

   Combines this System.Delegate with the specified System.Delegate to form a new delegate.

  

   follow: The delegate to combine with this delegate.

   Returns: A delegate that is the new root of the System.MulticastDelegate invocation list.
  """
  pass
 def DynamicInvokeImpl(self,*args):
  """
  DynamicInvokeImpl(self: Delegate,args: Array[object]) -> object

  

   Dynamically invokes (late-bound) the method represented by the current delegate.

  

   args: An array of objects that are the arguments to pass to the method represented by the current 

    delegate.-or- null,if the method represented by the current delegate does not require 

    arguments.

  

   Returns: The object returned by the method represented by the delegate.
  """
  pass
 def EndInvoke(self,result):
  """ EndInvoke(self: StrokeHitEventHandler,result: IAsyncResult) """
  pass
 def GetMethodImpl(self,*args):
  """
  GetMethodImpl(self: MulticastDelegate) -> MethodInfo

  

   Returns a static method represented by the current System.MulticastDelegate.

   Returns: A static method represented by the current System.MulticastDelegate.
  """
  pass
 def Invoke(self,sender,e):
  """ Invoke(self: StrokeHitEventHandler,sender: object,e: StrokeHitEventArgs) """
  pass
 def RemoveImpl(self,*args):
  """
  RemoveImpl(self: MulticastDelegate,value: Delegate) -> Delegate

  

   Removes an element from the invocation list of this System.MulticastDelegate that is equal to 

    the specified delegate.

  

  

   value: The delegate to search for in the invocation list.

   Returns: If value is found in the invocation list for this instance,then a new System.Delegate without 

    value in its invocation list; otherwise,this instance with its original invocation list.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,object,method):
  """ __new__(cls: type,object: object,method: IntPtr) """
  pass
 def __reduce_ex__(self,*args):
  pass

class StylusPointsReplacedEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Ink.Stroke.StylusPointsReplaced event.

 

 StylusPointsReplacedEventArgs(newStylusPoints: StylusPointCollection,previousStylusPoints: StylusPointCollection)
 """
 @staticmethod
 def __new__(self,newStylusPoints,previousStylusPoints):
  """ __new__(cls: type,newStylusPoints: StylusPointCollection,previousStylusPoints: StylusPointCollection) """
  pass
 NewStylusPoints=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the new System.Windows.Input.StylusPointCollection for the System.Windows.Ink.Stroke.



Get: NewStylusPoints(self: StylusPointsReplacedEventArgs) -> StylusPointCollection



"""

 PreviousStylusPoints=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the replaced System.Windows.Input.StylusPointCollection.



Get: PreviousStylusPoints(self: StylusPointsReplacedEventArgs) -> StylusPointCollection



"""



class StylusPointsReplacedEventHandler(MulticastDelegate,ICloneable,ISerializable):
 """
 Represents the method that will handle the System.Windows.Ink.Stroke.StylusPointsReplaced event of a System.Windows.Ink.Stroke.

 

 StylusPointsReplacedEventHandler(object: object,method: IntPtr)
 """
 def BeginInvoke(self,sender,e,callback,object):
  """ BeginInvoke(self: StylusPointsReplacedEventHandler,sender: object,e: StylusPointsReplacedEventArgs,callback: AsyncCallback,object: object) -> IAsyncResult """
  pass
 def CombineImpl(self,*args):
  """
  CombineImpl(self: MulticastDelegate,follow: Delegate) -> Delegate

  

   Combines this System.Delegate with the specified System.Delegate to form a new delegate.

  

   follow: The delegate to combine with this delegate.

   Returns: A delegate that is the new root of the System.MulticastDelegate invocation list.
  """
  pass
 def DynamicInvokeImpl(self,*args):
  """
  DynamicInvokeImpl(self: Delegate,args: Array[object]) -> object

  

   Dynamically invokes (late-bound) the method represented by the current delegate.

  

   args: An array of objects that are the arguments to pass to the method represented by the current 

    delegate.-or- null,if the method represented by the current delegate does not require 

    arguments.

  

   Returns: The object returned by the method represented by the delegate.
  """
  pass
 def EndInvoke(self,result):
  """ EndInvoke(self: StylusPointsReplacedEventHandler,result: IAsyncResult) """
  pass
 def GetMethodImpl(self,*args):
  """
  GetMethodImpl(self: MulticastDelegate) -> MethodInfo

  

   Returns a static method represented by the current System.MulticastDelegate.

   Returns: A static method represented by the current System.MulticastDelegate.
  """
  pass
 def Invoke(self,sender,e):
  """ Invoke(self: StylusPointsReplacedEventHandler,sender: object,e: StylusPointsReplacedEventArgs) """
  pass
 def RemoveImpl(self,*args):
  """
  RemoveImpl(self: MulticastDelegate,value: Delegate) -> Delegate

  

   Removes an element from the invocation list of this System.MulticastDelegate that is equal to 

    the specified delegate.

  

  

   value: The delegate to search for in the invocation list.

   Returns: If value is found in the invocation list for this instance,then a new System.Delegate without 

    value in its invocation list; otherwise,this instance with its original invocation list.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,object,method):
  """ __new__(cls: type,object: object,method: IntPtr) """
  pass
 def __reduce_ex__(self,*args):
  pass

class StylusTip(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the tip to be used to draw a System.Windows.Ink.Stroke.

 

 enum StylusTip,values: Ellipse (1),Rectangle (0)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Ellipse=None
 Rectangle=None
 value__=None





class DataGridViewElement(object):
 """
 Provides the base class for elements of a System.Windows.Forms.DataGridView control.

 

 DataGridViewElement()
 """
 def OnDataGridViewChanged(self,*args):
  """
  OnDataGridViewChanged(self: DataGridViewElement)

   Called when the element is associated with a different System.Windows.Forms.DataGridView.
  """
  pass
 def RaiseCellClick(self,*args):
  """
  RaiseCellClick(self: DataGridViewElement,e: DataGridViewCellEventArgs)

   Raises the System.Windows.Forms.DataGridView.CellClick event.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def RaiseCellContentClick(self,*args):
  """
  RaiseCellContentClick(self: DataGridViewElement,e: DataGridViewCellEventArgs)

   Raises the System.Windows.Forms.DataGridView.CellContentClick event.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def RaiseCellContentDoubleClick(self,*args):
  """
  RaiseCellContentDoubleClick(self: DataGridViewElement,e: DataGridViewCellEventArgs)

   Raises the System.Windows.Forms.DataGridView.CellContentDoubleClick event.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def RaiseCellValueChanged(self,*args):
  """
  RaiseCellValueChanged(self: DataGridViewElement,e: DataGridViewCellEventArgs)

   Raises the System.Windows.Forms.DataGridView.CellValueChanged event.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def RaiseDataError(self,*args):
  """
  RaiseDataError(self: DataGridViewElement,e: DataGridViewDataErrorEventArgs)

   Raises the System.Windows.Forms.DataGridView.DataError event.

  

   e: A System.Windows.Forms.DataGridViewDataErrorEventArgs that contains the event data.
  """
  pass
 def RaiseMouseWheel(self,*args):
  """
  RaiseMouseWheel(self: DataGridViewElement,e: MouseEventArgs)

   Raises the System.Windows.Forms.Control.MouseWheel event.

  

   e: A System.Windows.Forms.MouseEventArgs that contains the event data.
  """
  pass
 DataGridView=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Forms.DataGridView control associated with this element.



Get: DataGridView(self: DataGridViewElement) -> DataGridView



"""

 State=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the user interface (UI) state of the element.



Get: State(self: DataGridViewElement) -> DataGridViewElementStates



"""





"""
View Wrappers

"""  #

import rpw
from rpw import revit, DB
from rpw.db.element import Element
from rpw.db.pattern import LinePatternElement, FillPatternElement
from rpw.db.collector import Collector
from rpw.base import BaseObjectWrapper
from rpw.utils.coerce import to_element_ids, to_element_id, to_element
from rpw.utils.coerce import to_category_id, to_iterable
from rpw.exceptions import RpwTypeError, RpwCoerceError
from rpw.utils.logger import logger


class View(Element):
    """
    This is the main View View Wrapper - wraps ``DB.View``.
    All other View classes inherit from this class in the same way All
    API View classes inheir from ``DB.View``.

    This class is also used for view types that do not have more specific
    class, such as ``DB.Legend``, ``DB.ProjectBrowser``, ``DB.SystemBrowser``.

    As with other wrappers, you can use the Element() factory class to
    use the best wrapper available:

    >>> from rpw import db
    >>> wrapped_view = db.Element(some_view_plan)
    <rpw:ViewPlan>
    >>> wrapped_view = db.Element(some_legend)
    <rpw:View>
    >>> wrapped_view = db.Element(some_schedule)
    <rpw:ViewSchedule>


    >>> wrapped_view = db.Element(some_view_plan)
    >>> wrapped_view.view_type
    <rpw:ViewType | view_type: FloorPlan>
    >>> wrapped_view.view_family_type
    <rpw:ViewFamilyType % ..DB.ViewFamilyType | view_family:FloorPlan name:Floor Plan id:1312>
    >>> wrapped_view.view_family
    <rpw:ViewFamily | family: FloorPlan>
    >>> wrapped_view.siblings
    [<rpw:ViewFamilyType % ..DB.ViewFamilyType> ... ]

    View wrappers classes are collectible:

    >>> rpw.db.ViewPlan.collect()
    <rpw:Collector % ..DB.FilteredElementCollector | count:5>
    >>> rpw.db.View3D.collect(where=lambda x: x.Name='MyView')
    <rpw:Collector % ..DB.FilteredElementCollector | count:1>

    """

    _revit_object_category = DB.BuiltInCategory.OST_Views
    _revit_object_class = DB.View
    _collector_params = {'of_class': _revit_object_class, 'is_type': False}

    @property
    def view_type(self):
        """ ViewType attribute """
        return ViewType(self._revit_object.ViewType)

    @property
    def view_family_type(self):
        """ ViewFamilyType attribute """
        # NOTE: This can return Empty, as Some Views like SystemBrowser have no Type
        view_type_id = self._revit_object.GetTypeId()
        view_type = self.doc.GetElement(view_type_id)
        if view_type:
            return ViewFamilyType(self.doc.GetElement(view_type_id))

    @property
    def view_family(self):
        """ ViewFamily attribute """
        # Some Views don't have a ViewFamilyType
        return getattr(self.view_family_type, 'view_family', None)

    @property
    def siblings(self):
        """ Collect all views of the same ``ViewType`` """
        return self.view_type.views

    @property
    def override(self):
        """ Access to overrides.

        For more information see :any:`OverrideGraphicSettings`

        >>> from rpw import db
        >>> wrapped_view = db.Element(some_view)
        >>> wrapped_view.override.projection_line(element, color=[0,255,0])
        >>> wrapped_view.override.cut_line(category, weight=5)

        """
        return OverrideGraphicSettings(self)

    def change_type(self, type_reference):
        raise NotImplemented
        # self._revit_object.ChangeTypeId(type_reference)

    def __repr__(self):
        return super(View, self).__repr__(data={
                                'view_name': self.name,
                                'view_family_type': getattr(self.view_family_type, 'name', None),
                                'view_type': self.view_type.name,
                                'view_family': getattr(self.view_family, 'name', None)
                                                })


class ViewPlan(View):
    """
    ViewPlan Wrapper.

    ``ViewType`` is ViewType.FloorPlan or  ViewType.CeilingPlan

    """
    _revit_object_class = DB.ViewPlan
    _collector_params = {'of_class': _revit_object_class, 'is_type': False}

    @property
    def level(self):
        return self._revit_object.GenLevel


class ViewSheet(View):
    """ ViewSheet Wrapper. ``ViewType`` is ViewType.DrawingSheet """
    _revit_object_class = DB.ViewSheet
    _collector_params = {'of_class': _revit_object_class, 'is_type': False}


class ViewSchedule(View):
    """ ViewSchedule Wrapper. ``ViewType`` is ViewType.Schedule """
    _revit_object_class = DB.ViewSchedule
    _collector_params = {'of_class': _revit_object_class, 'is_type': False}


class ViewSection(View):
    """ DB.ViewSection Wrapper. ``ViewType`` is ViewType.DrawingSheet """
    _revit_object_class = DB.ViewSection
    _collector_params = {'of_class': _revit_object_class, 'is_type': False}


class View3D(View):
    """ DB.View3D Wrapper. ``ViewType`` is ViewType.ThreeD """
    _revit_object_class = DB.View3D
    _collector_params = {'of_class': _revit_object_class, 'is_type': False}


class ViewFamilyType(Element):
    """ View Family Type Wrapper """
    _revit_object_class = DB.ViewFamilyType
    _collector_params = {'of_class': _revit_object_class, 'is_type': True}

    @property
    def view_family(self):
        """ Returns ViewFamily Enumerator """
        # Autodesk.Revit.DB.ViewFamily.FloorPlan
        return ViewFamily(self._revit_object.ViewFamily)

    @property
    def views(self):
        """ Collect All Views of the same ViewFamilyType """
        views = Collector(of_class='View').get_elements(wrapped=True)
        return [view for view in views if
                getattr(view.view_family_type, '_revit_object', None) == self.unwrap()]

    def __repr__(self):
        return super(ViewFamilyType, self).__repr__(data={'name': self.name,
                                                          'view_family': self.view_family.name,
                                                          })


class ViewFamily(BaseObjectWrapper):
    """ ViewFamily Enumerator Wrapper.
    An enumerated type that corresponds to the type of a Revit view.
    http://www.revitapidocs.com/2015/916ed7b6-0a2e-c607-5d35-9ff9303b1f46.htm

    This is returned on view.ViewFamily
    AreaPlan, CeilingPlan, CostReport
    Detail, Drafting, Elevation
    FloorPlan, GraphicalColumnSchedule, ImageView, Legend
    LoadsReport, PanelSchedule, PressureLossReport
    Schedule, Section, Sheet, StructuralPlan
    ThreeDimensional, Walkthrough
    """
    _revit_object_class = DB.ViewFamily

    @property
    def name(self):
        """ ToString() of View Family Enumerator """
        return self._revit_object.ToString()

    @property
    def views(self):
        """ Collect All Views of the same ViewFamily """
        views = Collector(of_class='View').get_elements(wrapped=True)
        return [view for view in views if
                getattr(view.view_family, '_revit_object', None) == self.unwrap()]

    def __repr__(self):
        return super(ViewFamily, self).__repr__(data={'family': self.name})


class ViewType(BaseObjectWrapper):
    """ ViewType Wrapper.
    An enumerated type listing available view types.
    http://www.revitapidocs.com/2015/bf04dabc-05a3-baf0-3564-f96c0bde3400.htm

    Can be on of the following types:
        AreaPlan ,CeilingPlan, ColumnSchedule, CostReport,
        Detail, DraftingView, DrawingSheet, Elevation, EngineeringPlan,
        FloorPlan, Internal, Legend,
        LoadsReport, PanelSchedule, PresureLossReport,
        ProjectBrowser, Rendering, Report,
        Schedule, Section, SystemBrowser,
        ThreeD, Undefined, Walkthrough
    """
    _revit_object_class = DB.ViewType

    @property
    def name(self):
        """ ToString() of View Family Enumerator """
        return self._revit_object.ToString()

    @property
    def views(self):
        """ Collect All Views of the same ViewType """
        views = Collector(of_class='View').get_elements(wrapped=True)
        return [view for view in views if view.view_type.unwrap() == self.unwrap()]

    def __repr__(self):
        return super(ViewType, self).__repr__(data={'view_type': self.name})


class ViewPlanType(BaseObjectWrapper):
    """
    Enumerator
        ViewPlanType.FloorPlan, ViewPlanType.CeilingPlan
    No Wrapper Need. Enum is only used as arg for when creating ViewPlan
    """


class OverrideGraphicSettings(BaseObjectWrapper):

    """ Internal Wrapper for OverrideGraphicSettings - view.override



    >>> from rpw import db
    >>> wrapped_view = db.Element(some_view)
    >>> wrapped_view.override.projection_line(target, color=(255,0,0))
    >>> wrapped_view.override.projection_fill(target, color=(0,0,255), pattern=pattern_id)
    >>> wrapped_view.override.cut_line(target, color=(0,0,255), weight=2)
    >>> wrapped_view.override.cut_fill(target, visible=False)
    >>> wrapped_view.override.transparency(target, 50)
    >>> wrapped_view.override.halftone(target, True)
    >>> wrapped_view.override.detail_level(target, 'Coarse')

    Note:
        Target can be any of the following:

        * Element
        * ElementId
        * BuiltInCategory Enum
        * BuiltInCategory Fuzzy Name (See :func:`fuzzy_get`)
        * Category_id
        * An iterable containing any of the above types

    """

    # TODO: Pattern: Add pattern_id from name. None sets InvalidElementId
    # TODO: Weight: None to set InvalidPenNumber
    # TODO: Color: Add color from name util
    # ISSUE: Cannot set LinePatterns to Solid because it's not collectible:
    # https://forums.autodesk.com/t5/revit-api-forum/solid-linepattern/td-p/4651067

    _revit_object_class = DB.OverrideGraphicSettings

    def __init__(self, wrapped_view):
        super(OverrideGraphicSettings, self).__init__(DB.OverrideGraphicSettings())
        self.view = wrapped_view.unwrap()

    def _set_overrides(self, target):
        targets = to_iterable(target)
        for target in targets:
            try:
                category_id = to_category_id(target)
                self._set_category_overrides(category_id)
            except (RpwTypeError, RpwCoerceError) as errmsg:
                logger.debug('Not Category, Trying Element Override')
                element_id = to_element_id(target)
                self._set_element_overrides(element_id)

    def _set_element_overrides(self, element_id):
        self.view.SetElementOverrides(element_id, self._revit_object)

    def _set_category_overrides(self, category_id):
        self.view.SetCategoryOverrides(category_id, self._revit_object)

    def match_element(self, target, element_to_match):
        """
        Matches the settings of another element

        Args:
            target (``Element``, ``ElementId``, ``Category``): Target
                Element(s) or Category(ies) to apply override. Can be list.
            element_to_match (``Element``, ``ElementId``): Element to match

        """
        element_to_match = to_element_id(element_to_match)

        self._revit_object = self.view.GetElementOverrides(element_to_match)
        self._set_overrides(target)

    def projection_line(self, target, color=None, pattern=None, weight=None):
        """
        Sets ProjectionLine overrides

        Args:
            target (``Element``, ``ElementId``, ``Category``): Target
                Element(s) or Category(ies) to apply override. Can be list.
            color (``tuple``, ``list``): RGB Colors [ex. (255, 255, 0)]
            pattern (``DB.ElementId``): ElementId of Pattern
            weight (``int``,``None``): Line weight must be a positive integer
                less than 17 or None(sets invalidPenNumber)

        """
        if color:
            Color = DB.Color(*color)
            self._revit_object.SetProjectionLineColor(Color)
        if pattern:
            line_pattern = LinePatternElement.by_name_or_element_ref(pattern)
            self._revit_object.SetProjectionLinePatternId(line_pattern.Id)
        if weight:
            self._revit_object.SetProjectionLineWeight(weight)

        self._set_overrides(target)

    def cut_line(self, target, color=None, pattern=None, weight=None):
        """
        Sets CutLine Overrides

        Args:
            target (``Element``, ``ElementId``, ``Category``): Target
                Element(s) or Category(ies) to apply override. Can be list.
            color (``tuple``, ``list``): RGB Colors [ex. (255, 255, 0)]
            pattern (``DB.ElementId``): ElementId of Pattern
            weight (``int``,``None``): Line weight must be a positive integer
                less than 17 or None(sets invalidPenNumber)
        """
        if color:
            Color = DB.Color(*color)
            self._revit_object.SetCutLineColor(Color)
        if pattern:
            line_pattern = LinePatternElement.by_name_or_element_ref(pattern)
            self._revit_object.SetCutLinePatternId(line_pattern.Id)
        if weight:
            self._revit_object.SetCutLineWeight(weight)

        self._set_overrides(target)

    def projection_fill(self, target, color=None, pattern=None, visible=None):
        """
        Sets ProjectionFill overrides

        Args:
            target (``Element``, ``ElementId``, ``Category``): Target
                Element(s) or Category(ies) to apply override. Can be list.
            color (``tuple``, ``list``): RGB Colors [ex. (255, 255, 0)]
            pattern (``DB.ElementId``): ElementId of Pattern
            visible (``bool``): Cut Fill Visibility
        """
        if color:
            Color = DB.Color(*color)
            self._revit_object.SetProjectionFillColor(Color)
        if pattern:
            fill_pattern = FillPatternElement.by_name_or_element_ref(pattern)
            self._revit_object.SetProjectionFillPatternId(fill_pattern.Id)
        if visible is not None:
            self._revit_object.SetProjectionFillPatternVisible(visible)

        self._set_overrides(target)

    def cut_fill(self, target, color=None, pattern=None, visible=None):
        """
        Sets CutFill overrides

        Args:
            target (``Element``, ``ElementId``, ``Category``): Target
                Element(s) or Category(ies) to apply override. Can be list.
            color (``tuple``, ``list``): RGB Colors [ex. (255, 255, 0)]
            pattern (``DB.ElementId``): ElementId of Pattern
            visible (``bool``): Cut Fill Visibility
        """

        if color:
            Color = DB.Color(*color)
            self._revit_object.SetCutFillColor(Color)
        if pattern:
            fill_pattern = FillPatternElement.by_name_or_element_ref(pattern)
            self._revit_object.SetCutFillPatternId(fill_pattern.Id)
        if visible is not None:
            self._revit_object.SetCutFillPatternVisible(visible)

        self._set_overrides(target)

    def transparency(self, target, transparency):
        """
        Sets SurfaceTransparency override

        Args:
            target (``Element``, ``ElementId``, ``Category``): Target
                Element(s) or Category(ies) to apply override. Can be list.
            transparency (``int``): Value of the transparency of the projection surface
                                    (0 = opaque, 100 = fully transparent)
        """
        self._revit_object.SetSurfaceTransparency(transparency)
        self._set_overrides(target)

    def halftone(self, target, halftone):
        """
        Sets Halftone Override

        Args:
            target (``Element``, ``ElementId``, ``Category``): Target
                Element(s) or Category(ies) to apply override. Can be list.
            halftone (``bool``): Halftone
        """
        self._revit_object.SetHalftone(halftone)
        self._set_overrides(target)

    def detail_level(self, target, detail_level):
        """
        Sets DetailLevel Override. DetailLevel can be Enumeration memeber of
        DB.ViewDetailLevel or its name as a string. The Options are:

            * Coarse
            * Medium
            * Fine

        Args:
            target (``Element``, ``ElementId``, ``Category``): Target
                Element(s) or Category(ies) to apply override. Can be list.
            detail_level (``DB.ViewDetailLevel``, ``str``): Detail Level
                Enumerator or name
        """

        if isinstance(detail_level, str):
            detail_level = getattr(DB.ViewDetailLevel, detail_level)

        self._revit_object.SetDetailLevel(detail_level)
        self._set_overrides(target)



class Boolean(int):
 """ Represents a Boolean value. """
 @staticmethod
 def __new__(self,*args): #cannot find CLR constructor
  """
  __new__(cls: object,o: object) -> bool

  __new__(cls: object) -> object
  """
  pass



class EndpointPermission(object):
 """ Defines an endpoint that is authorized by a System.Net.SocketPermission instance. """
 def Equals(self,obj):
  """
  Equals(self: EndpointPermission,obj: object) -> bool

  

   Determines whether the specified System.Object is equal to the current 

    System.Net.SocketPermission instance.

  

  

   obj: The specified System.Object

   Returns: true if the specified System.Object is equal to the current System.Object; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: EndpointPermission) -> int

  

   Serves as a hash function for a particular System.Net.SocketPermission instance.

   Returns: A hash code for the current System.Object.
  """
  pass
 def ToString(self):
  """
  ToString(self: EndpointPermission) -> str

  

   Returns a string that represents the current System.Net.EndpointPermission instance.

   Returns: A string that represents the current System.Net.EndpointPermission instance.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __ne__(self,*args):
  pass
 Hostname=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the DNS host name or IP address of the server that is associated with this endpoint.



Get: Hostname(self: EndpointPermission) -> str



"""

 Port=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the network port number that is associated with this endpoint.



Get: Port(self: EndpointPermission) -> int



"""

 Transport=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the transport type that is associated with this endpoint.



Get: Transport(self: EndpointPermission) -> TransportType



"""





class RelatedImageListAttribute(Attribute,_Attribute):
 """
 Indicates which System.Windows.Forms.ImageList a property is related to.

 

 RelatedImageListAttribute(relatedImageList: str)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,relatedImageList):
  """ __new__(cls: type,relatedImageList: str) """
  pass
 RelatedImageList=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of the related System.Windows.Forms.ImageList



Get: RelatedImageList(self: RelatedImageListAttribute) -> str



"""





class FormClosedEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Forms.Form.FormClosed event.

 

 FormClosedEventArgs(closeReason: CloseReason)
 """
 @staticmethod
 def __new__(self,closeReason):
  """ __new__(cls: type,closeReason: CloseReason) """
  pass
 CloseReason=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates why the form was closed.



Get: CloseReason(self: FormClosedEventArgs) -> CloseReason



"""





"""Module exceptions."""


# Revit server execeptions ----------------------------------------------------
class ServerVersionNotSupported(Exception):
    """Server version not supported exception."""

    pass


class ServerConnectionError(Exception):
    """Server connection exception."""

    pass


class ServerTimeoutError(Exception):
    """Server timeout error."""

    pass


class UnhandledException(Exception):
    """General exception for any unhandled exceptions."""

    pass


# Revit Server API http status codes  -----------------------------------------
# 400
class ServerBadRequestError(Exception):
    """Server bad request error."""

    pass


# 403
class ServerForbiddenError(Exception):
    """Server forbidden command error."""

    pass


# 404
class ServerFileNotFound(Exception):
    """Server file or folder not found error."""

    pass


# 405
class ServerMethodNotAllowedError(Exception):
    """Server method not allowed error."""

    pass


# 414
class ServerURITooLongError(Exception):
    """Server uri too long error."""

    pass


# 500
class ServerInternalError(Exception):
    """Server internal error."""

    pass


# 501
class ServerNotImplemented(Exception):
    """Server not implemented error."""

    pass


# 503
class ServerServiceUnavailableError(Exception):
    """Server service unavailable error."""

    pass



class InitializationEventAttribute(Attribute,_Attribute):
 """
 Specifies which event is raised on initialization. This class cannot be inherited.

 

 InitializationEventAttribute(eventName: str)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,eventName):
  """ __new__(cls: type,eventName: str) """
  pass
 EventName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of the initialization event.



Get: EventName(self: InitializationEventAttribute) -> str



"""





class INestedContainer(IContainer,IDisposable):
 """ Provides functionality for nested containers,which logically contain zero or more other components and are owned by a parent component. """
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 Owner=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the owning component for the nested container.



Get: Owner(self: INestedContainer) -> IComponent



"""





# encoding: utf-8
# module System.IO calls itself IO
# from mscorlib,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089,System,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes
from __init___parts.BinaryReader import BinaryReader
from __init___parts.BinaryWriter import BinaryWriter
from __init___parts.Stream import Stream
from __init___parts.BufferedStream import BufferedStream
from __init___parts.Directory import Directory
from __init___parts.FileSystemInfo import FileSystemInfo
from __init___parts.DirectoryInfo import DirectoryInfo
from __init___parts.IOException import IOException
from __init___parts.DirectoryNotFoundException import DirectoryNotFoundException
from __init___parts.DriveInfo import DriveInfo
from __init___parts.DriveNotFoundException import DriveNotFoundException
from __init___parts.DriveType import DriveType
from __init___parts.EndOfStreamException import EndOfStreamException
from __init___parts.ErrorEventArgs import ErrorEventArgs
from __init___parts.ErrorEventHandler import ErrorEventHandler
from __init___parts.File import File
from __init___parts.FileAccess import FileAccess
from __init___parts.FileAttributes import FileAttributes
from __init___parts.FileInfo import FileInfo
from __init___parts.FileLoadException import FileLoadException
from __init___parts.FileMode import FileMode
from __init___parts.FileNotFoundException import FileNotFoundException
from __init___parts.FileOptions import FileOptions
from __init___parts.FileShare import FileShare
from __init___parts.FileStream import FileStream
from __init___parts.FileSystemEventArgs import FileSystemEventArgs
from __init___parts.FileSystemEventHandler import FileSystemEventHandler
from __init___parts.FileSystemWatcher import FileSystemWatcher
from __init___parts.InternalBufferOverflowException import InternalBufferOverflowException
from __init___parts.InvalidDataException import InvalidDataException
from __init___parts.IODescriptionAttribute import IODescriptionAttribute
from __init___parts.MemoryStream import MemoryStream
from __init___parts.NotifyFilters import NotifyFilters
from __init___parts.Path import Path
from __init___parts.PathTooLongException import PathTooLongException
from __init___parts.RenamedEventArgs import RenamedEventArgs
from __init___parts.RenamedEventHandler import RenamedEventHandler
from __init___parts.SearchOption import SearchOption
from __init___parts.SeekOrigin import SeekOrigin
from __init___parts.TextReader import TextReader
from __init___parts.StreamReader import StreamReader
from __init___parts.TextWriter import TextWriter
from __init___parts.StreamWriter import StreamWriter
from __init___parts.StringReader import StringReader
from __init___parts.StringWriter import StringWriter
from __init___parts.UnmanagedMemoryAccessor import UnmanagedMemoryAccessor
from __init___parts.UnmanagedMemoryStream import UnmanagedMemoryStream
from __init___parts.WaitForChangedResult import WaitForChangedResult
from __init___parts.WatcherChangeTypes import WatcherChangeTypes



class HttpListener(object,IDisposable):
 """
 Provides a simple,programmatically controlled HTTP protocol listener. This class cannot be inherited.

 

 HttpListener()
 """
 def Abort(self):
  """
  Abort(self: HttpListener)

   Shuts down the System.Net.HttpListener object immediately,discarding all currently queued 

    requests.
  """
  pass
 def BeginGetContext(self,callback,state):
  """
  BeginGetContext(self: HttpListener,callback: AsyncCallback,state: object) -> IAsyncResult

  

   Begins asynchronously retrieving an incoming request.

  

   callback: An System.AsyncCallback delegate that references the method to invoke when a client request is 

    available.

  

   state: A user-defined object that contains information about the operation. This object is passed to 

    the callback delegate when the operation completes.

  

   Returns: An System.IAsyncResult object that indicates the status of the asynchronous operation.
  """
  pass
 def Close(self):
  """
  Close(self: HttpListener)

   Shuts down the System.Net.HttpListener.
  """
  pass
 def EndGetContext(self,asyncResult):
  """
  EndGetContext(self: HttpListener,asyncResult: IAsyncResult) -> HttpListenerContext

  

   Completes an asynchronous operation to retrieve an incoming client request.

  

   asyncResult: An System.IAsyncResult object that was obtained when the asynchronous operation was started.

   Returns: An System.Net.HttpListenerContext object that represents the client request.
  """
  pass
 def GetContext(self):
  """
  GetContext(self: HttpListener) -> HttpListenerContext

  

   Waits for an incoming request and returns when one is received.

   Returns: An System.Net.HttpListenerContext object that represents a client request.
  """
  pass
 def GetContextAsync(self):
  """ GetContextAsync(self: HttpListener) -> Task[HttpListenerContext] """
  pass
 def Start(self):
  """
  Start(self: HttpListener)

   Allows this instance to receive incoming requests.
  """
  pass
 def Stop(self):
  """
  Stop(self: HttpListener)

   Causes this instance to stop receiving incoming requests.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 AuthenticationSchemes=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the scheme used to authenticate clients.



Get: AuthenticationSchemes(self: HttpListener) -> AuthenticationSchemes



Set: AuthenticationSchemes(self: HttpListener)=value

"""

 AuthenticationSchemeSelectorDelegate=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the delegate called to determine the protocol used to authenticate clients.



Get: AuthenticationSchemeSelectorDelegate(self: HttpListener) -> AuthenticationSchemeSelector



Set: AuthenticationSchemeSelectorDelegate(self: HttpListener)=value

"""

 DefaultServiceNames=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a default list of Service Provider Names (SPNs) as determined by registered prefixes.



Get: DefaultServiceNames(self: HttpListener) -> ServiceNameCollection



"""

 ExtendedProtectionPolicy=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get or set the System.Security.Authentication.ExtendedProtection.ExtendedProtectionPolicy to use for extended protection for a session.



Get: ExtendedProtectionPolicy(self: HttpListener) -> ExtendedProtectionPolicy



Set: ExtendedProtectionPolicy(self: HttpListener)=value

"""

 ExtendedProtectionSelectorDelegate=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get or set the delegate called to determine the System.Security.Authentication.ExtendedProtection.ExtendedProtectionPolicy to use for each request.



Get: ExtendedProtectionSelectorDelegate(self: HttpListener) -> ExtendedProtectionSelector



Set: ExtendedProtectionSelectorDelegate(self: HttpListener)=value

"""

 IgnoreWriteExceptions=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a System.Boolean value that specifies whether your application receives exceptions that occur when an System.Net.HttpListener sends the response to the client.



Get: IgnoreWriteExceptions(self: HttpListener) -> bool



Set: IgnoreWriteExceptions(self: HttpListener)=value

"""

 IsListening=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether System.Net.HttpListener has been started.



Get: IsListening(self: HttpListener) -> bool



"""

 Prefixes=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the Uniform Resource Identifier (URI) prefixes handled by this System.Net.HttpListener object.



Get: Prefixes(self: HttpListener) -> HttpListenerPrefixCollection



"""

 Realm=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the realm,or resource partition,associated with this System.Net.HttpListener object.



Get: Realm(self: HttpListener) -> str



Set: Realm(self: HttpListener)=value

"""

 TimeoutManager=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: TimeoutManager(self: HttpListener) -> HttpListenerTimeoutManager



"""

 UnsafeConnectionNtlmAuthentication=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a System.Boolean value that controls whether,when NTLM is used,additional requests using the same Transmission Control Protocol (TCP) connection are required to authenticate.



Get: UnsafeConnectionNtlmAuthentication(self: HttpListener) -> bool



Set: UnsafeConnectionNtlmAuthentication(self: HttpListener)=value

"""


 ExtendedProtectionSelector=None
 IsSupported=True




from typing import Tuple, Set, Iterable, List


class Room(SpatialElement):
    @property
    def ClosedShell(self) -> GeometryElement: ...
    @property
    def UpperLimit(self) -> Level: ...
    @UpperLimit.setter
    def UpperLimit(self, plev: Level) -> None: ...
    @property
    def LimitOffset(self) -> float: ...
    @LimitOffset.setter
    def LimitOffset(self, vLimitOffset: float) -> None: ...
    @property
    def BaseOffset(self) -> float: ...
    @BaseOffset.setter
    def BaseOffset(self, vBaseOffset: float) -> None: ...
    @property
    def UnboundedHeight(self) -> float: ...
    @property
    def Volume(self) -> float: ...
    def Unplace(self) -> None: ...
    def IsPointInRoom(self, point: XYZ) -> bool: ...


class RoomTagType(FamilySymbol):


class FasciaType(HostedSweepType):


class GutterType(HostedSweepType):


class Fascia(HostedSweep):
    @property
    def FasciaType(self) -> FasciaType: ...
    @FasciaType.setter
    def FasciaType(self, value: FasciaType) -> None: ...
    def AddSegment(self, targetRef: Reference) -> None: ...


class Gutter(HostedSweep):
    @property
    def GutterType(self) -> GutterType: ...
    @GutterType.setter
    def GutterType(self, value: GutterType) -> None: ...
    def AddSegment(self, targetRef: Reference) -> None: ...


class RoomTag(SpatialElementTag):
    @property
    def Room(self) -> Room: ...
    @property
    def RoomTagType(self) -> RoomTagType: ...
    @RoomTagType.setter
    def RoomTagType(self, A_0: RoomTagType) -> None: ...
    @property
    def IsInRoom(self) -> bool: ...
    @property
    def TaggedLocalRoomId(self) -> ElementId: ...
    @property
    def TaggedRoomId(self) -> LinkElementId: ...


class TopographySurface(Element):
    @property
    def ArePointsEditable(self) -> bool: ...
    @property
    def IsSiteSubRegion(self) -> bool: ...
    @property
    def IsAssociatedWithBuildingPad(self) -> bool: ...
    @property
    def AssociatedBuildingPadId(self) -> ElementId: ...
    @property
    def MaterialId(self) -> ElementId: ...
    @MaterialId.setter
    def MaterialId(self, materialId: ElementId) -> None: ...
    @overload
    def Create(document: Document, points: List[XYZ], facets: List[PolymeshFacet]) -> TopographySurface: ...
    @overload
    def Create(document: Document, points: List[XYZ]) -> TopographySurface: ...
    def AddPoints(self, points: List[XYZ]) -> None: ...
    def DeletePoints(self, points: List[XYZ]) -> None: ...
    def MovePoint(self, movedPoint: XYZ, targetPoint: XYZ) -> None: ...
    def MovePoints(self, movedPoints: List[XYZ], moveVector: XYZ) -> None: ...
    def ChangePointElevation(self, point: XYZ, elevationValue: float) -> None: ...
    def ChangePointsElevation(self, points: List[XYZ], elevationValue: float) -> None: ...
    def IsValidRegion(points: List[XYZ]) -> bool: ...
    def ArePointsDistinct(points: List[XYZ]) -> bool: ...
    def GetPoints(self) -> List[XYZ]: ...
    def IsBoundaryPoint(self, point: XYZ) -> bool: ...
    def ContainsPoint(self, point: XYZ) -> bool: ...
    def GetBoundaryPoints(self) -> List[XYZ]: ...
    def GetInteriorPoints(self) -> List[XYZ]: ...
    def FindPoints(self, boundingBox: Outline) -> List[XYZ]: ...
    def AsSiteSubRegion(self) -> SiteSubRegion: ...
    def GetHostedSubRegionIds(self) -> List[ElementId]: ...
    def IsValidFaceSet(facets: List[PolymeshFacet], points: List[XYZ]) -> bool: ...


class BalusterInfo:
    @property
    def BalusterFamilyId(self) -> ElementId: ...
    @BalusterFamilyId.setter
    def BalusterFamilyId(self, balusterFamilyId: ElementId) -> None: ...
    @property
    def Name(self) -> str: ...
    @Name.setter
    def Name(self, name: str) -> None: ...
    @property
    def BaseOffset(self) -> float: ...
    @BaseOffset.setter
    def BaseOffset(self, baseOffset: float) -> None: ...
    @property
    def TopOffset(self) -> float: ...
    @TopOffset.setter
    def TopOffset(self, topOffset: float) -> None: ...
    @property
    def Offset(self) -> float: ...
    @Offset.setter
    def Offset(self, offset: float) -> None: ...
    @property
    def DistanceFromPreviousOrSpace(self) -> float: ...
    @DistanceFromPreviousOrSpace.setter
    def DistanceFromPreviousOrSpace(self, distanceFromPreviousOrSpace: float) -> None: ...
    @property
    def BaseReferenceName(self) -> str: ...
    @BaseReferenceName.setter
    def BaseReferenceName(self, name: str) -> None: ...
    @property
    def TopReferenceName(self) -> str: ...
    @TopReferenceName.setter
    def TopReferenceName(self, name: str) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetReferenceNameForHost() -> str: ...
    def GetReferenceNameForTopRail() -> str: ...
    def Dispose(self) -> None: ...


class BalusterPattern:
    @property
    def EndSpace(self) -> float: ...
    @EndSpace.setter
    def EndSpace(self, endSpace: float) -> None: ...
    @property
    def PatternAngle(self) -> float: ...
    @PatternAngle.setter
    def PatternAngle(self, patternAngle: float) -> None: ...
    @property
    def ExcessLengthFillBalusterId(self) -> ElementId: ...
    @ExcessLengthFillBalusterId.setter
    def ExcessLengthFillBalusterId(self, excessLengthFillBalusterId: ElementId) -> None: ...
    @property
    def ExcessLengthFillSpacing(self) -> float: ...
    @ExcessLengthFillSpacing.setter
    def ExcessLengthFillSpacing(self, excessLengthFillSpacing: float) -> None: ...
    @property
    def BreakPattern(self) -> BreakPatternCondition: ...
    @BreakPattern.setter
    def BreakPattern(self, breakPattern: BreakPatternCondition) -> None: ...
    @property
    def DistributionJustification(self) -> PatternJustification: ...
    @DistributionJustification.setter
    def DistributionJustification(self, distributionJustification: PatternJustification) -> None: ...
    @property
    def Length(self) -> float: ...
    @property
    def IsValidObject(self) -> bool: ...
    def GetBalusterCount(self) -> int: ...
    def GetBaluster(self, index: int) -> BalusterInfo: ...
    def DuplicateBaluster(self, index: int) -> BalusterInfo: ...
    def RemoveBaluster(self, index: int) -> None: ...
    def Dispose(self) -> None: ...


class BalusterPlacement:
    @property
    def BalusterPattern(self) -> BalusterPattern: ...
    @property
    def PostPattern(self) -> PostPattern: ...
    @property
    def UseBalusterPerTreadOnStairs(self) -> bool: ...
    @UseBalusterPerTreadOnStairs.setter
    def UseBalusterPerTreadOnStairs(self, useBalusterPerTreadOnStairs: bool) -> None: ...
    @property
    def BalusterPerTreadNumber(self) -> int: ...
    @BalusterPerTreadNumber.setter
    def BalusterPerTreadNumber(self, balusterPerTreadNumber: int) -> None: ...
    @property
    def BalusterPerTreadFamilyId(self) -> ElementId: ...
    @BalusterPerTreadFamilyId.setter
    def BalusterPerTreadFamilyId(self, balusterPerTreadFamilyId: ElementId) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class PostPattern:
    @property
    def StartPost(self) -> BalusterInfo: ...
    @property
    def EndPost(self) -> BalusterInfo: ...
    @property
    def CornerPost(self) -> BalusterInfo: ...
    @property
    def CornerPostAngle(self) -> float: ...
    @CornerPostAngle.setter
    def CornerPostAngle(self, cornerPostAngle: float) -> None: ...
    @property
    def CornerPostCondition(self) -> BreakCornerCondition: ...
    @CornerPostCondition.setter
    def CornerPostCondition(self, cornerPostCondition: BreakCornerCondition) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class BuildingPad(CeilingAndFloor):
    @property
    def HostId(self) -> ElementId: ...
    @property
    def AssociatedTopographySurfaceId(self) -> ElementId: ...
    def Create(document: Document, buildingPadTypeId: ElementId, levelId: ElementId, curveLoops: List[CurveLoop]) -> BuildingPad: ...
    def GetBoundary(self) -> List[CurveLoop]: ...
    def SetBoundary(self, curveLoops: List[CurveLoop]) -> None: ...


class BreakPatternCondition:
    EachSegmentEnd = 0
    AnglesGreaterThan = 1
    Never = 2


class PatternJustification:
    Beginning = 0
    End = 1
    Center = 2
    SpreadPatternToFit = 3


class BreakCornerCondition:
    EachSegmentEnd = 0
    AnglesGreaterThan = 1
    Never = 2


class ContinuousRail(Element):
    @property
    def Length(self) -> float: ...
    @property
    def HostRailingId(self) -> ElementId: ...
    def GetPath(self) -> List[Curve]: ...
    def GetStartExtensionPath(self) -> List[Curve]: ...
    def GetEndExtensionPath(self) -> List[Curve]: ...
    def GetSupports(self) -> List[ElementId]: ...


class ContinuousRailType(ElementType):
    @property
    def StartOrBottomExtensionLength(self) -> float: ...
    @StartOrBottomExtensionLength.setter
    def StartOrBottomExtensionLength(self, StartOrBottomExtensionLength: float) -> None: ...
    @property
    def EndOrTopExtensionLength(self) -> float: ...
    @EndOrTopExtensionLength.setter
    def EndOrTopExtensionLength(self, EndOrTopExtensionLength: float) -> None: ...
    @property
    def ProfileId(self) -> ElementId: ...
    @ProfileId.setter
    def ProfileId(self, profileId: ElementId) -> None: ...
    @property
    def StartOrBottomExtensionStyle(self) -> RailExtensionStyle: ...
    @StartOrBottomExtensionStyle.setter
    def StartOrBottomExtensionStyle(self, StartOrBottomExtensionStyle: RailExtensionStyle) -> None: ...
    @property
    def EndOrTopExtensionStyle(self) -> RailExtensionStyle: ...
    @EndOrTopExtensionStyle.setter
    def EndOrTopExtensionStyle(self, EndOrTopExtensionStyle: RailExtensionStyle) -> None: ...
    @property
    def Transition(self) -> RailTransitionOption: ...
    @Transition.setter
    def Transition(self, Transition: RailTransitionOption) -> None: ...
    @property
    def DefaultJoinOption(self) -> RailTypeDefaultJoinOption: ...
    @DefaultJoinOption.setter
    def DefaultJoinOption(self, DefaultJoinOption: RailTypeDefaultJoinOption) -> None: ...
    @property
    def FilletRadius(self) -> float: ...
    @FilletRadius.setter
    def FilletRadius(self, filletRadius: float) -> None: ...
    @property
    def StartOrBottomTermination(self) -> ElementId: ...
    @StartOrBottomTermination.setter
    def StartOrBottomTermination(self, termination: ElementId) -> None: ...
    @property
    def EndOrTopTermination(self) -> ElementId: ...
    @EndOrTopTermination.setter
    def EndOrTopTermination(self, termination: ElementId) -> None: ...
    @property
    def Projection(self) -> float: ...
    @property
    def HandClearance(self) -> float: ...
    @HandClearance.setter
    def HandClearance(self, clearance: float) -> None: ...


class RailExtensionStyle:
    #None = 0
    Wall = 1
    Floor = 2
    Post = 3


class RailJoinOption:
    Miter = 0
    Fillet = 1
    ByType = -1


class RailTypeDefaultJoinOption:
    Miter = 0
    Fillet = 1


class RailConnectionOption:
    Trim = 0
    Weld = 1


class RailSupportsLayout:
    #None = 0
    FixedDistance = 1
    AlignWithRailingPosts = 2
    FixedNumber = 3
    MaxSpacing = 4
    MinSpacing = 5


class RailSupportJustification:
    Begin = 0
    Center = 1
    End = 2


class HandRailPosition:
    #None = 0
    Left = 1
    Right = 2
    LeftAndRight = 3


class RailTransitionOption:
    #None = 0
    Gooseneck = 1
    Simple = 2


class RailingPlacementPosition:
    Treads = 0
    Stringer = 1
    Undefined = -1


class RailingHeightCorrectionOption:
    ByType = 0
    Custom = 1


class RailingSlopeOption:
    ByHost = 0
    Flat = 1
    Sloped = 2


class RailAngledJoinOption:
    AddVerticalOrHorizontalSegments = 0
    NoConnector = 1


class RailTagentJoinOption:
    AddVerticalOrHorizontalSegments = 0
    NoConnector = 1
    ExtendRailsToMeet = 2


class RailingPathCurveJoinOption:
    ByType = 0
    ExtendRailsToMeet = 1
    AddVerticalOrHorizontalSegments = 2
    NoConnector = 3


class RailIndex:
    Top = 0
    LeftPrimary = 1
    RightPrimary = 2
    LeftSecondary = 3
    RightSecondary = 4


class NonContinuousRailInfo:
    @property
    def Name(self) -> str: ...
    @Name.setter
    def Name(self, name: str) -> None: ...
    @property
    def Height(self) -> float: ...
    @Height.setter
    def Height(self, height: float) -> None: ...
    @property
    def Offset(self) -> float: ...
    @Offset.setter
    def Offset(self, offset: float) -> None: ...
    @property
    def ProfileId(self) -> ElementId: ...
    @ProfileId.setter
    def ProfileId(self, profileId: ElementId) -> None: ...
    @property
    def MaterialId(self) -> ElementId: ...
    @MaterialId.setter
    def MaterialId(self, materialId: ElementId) -> None: ...
    @property
    def IsValidObject(self) -> bool: ...
    def IsValidNonContinuousRailHeight(self, height: float) -> bool: ...
    def IsValidNonContinuousRailName(self, name: str) -> bool: ...
    def IsValidNonContinuousRailProfile(self, profileId: ElementId) -> bool: ...
    def IsValidNonContinuousRailMaterial(self, materialId: ElementId) -> bool: ...
    def Dispose(self) -> None: ...


class NonContinuousRailStructure:
    @property
    def IsValidObject(self) -> bool: ...
    def GetNonContinuousRailCount(self) -> int: ...
    def AddNonContinuousRail(self, name: str, height: float, offset: float) -> NonContinuousRailInfo: ...
    def GetNonContinuousRail(self, index: int) -> NonContinuousRailInfo: ...
    def RemoveNonContinuousRail(self, index: int) -> None: ...
    def IsValidNonContinuousRailProfile(self, profileId: ElementId) -> bool: ...
    def Dispose(self) -> None: ...


class RoomFilter(ElementSlowFilter):
    def __init__(self): ...


class RoomTagFilter(ElementSlowFilter):
    def __init__(self): ...


class CutMarkType(ElementType):
    @property
    def CutMarkSymbolSize(self) -> float: ...
    @CutMarkSymbolSize.setter
    def CutMarkSymbolSize(self, CutMarkSymbolSize: float) -> None: ...
    @property
    def CutLineAngle(self) -> float: ...
    @CutLineAngle.setter
    def CutLineAngle(self, CutLineAngle: float) -> None: ...
    @property
    def CutLineExtension(self) -> float: ...
    @CutLineExtension.setter
    def CutLineExtension(self, CutLineExtension: float) -> None: ...
    @property
    def CutLineDistance(self) -> float: ...
    @CutLineDistance.setter
    def CutLineDistance(self, CutLineDistance: float) -> None: ...
    @property
    def CutMarkSymbol(self) -> CutMarkSymbol: ...
    @CutMarkSymbol.setter
    def CutMarkSymbol(self, cutMarkSymbol: CutMarkSymbol) -> None: ...
    @property
    def CutLineType(self) -> CutLineType: ...
    @CutLineType.setter
    def CutLineType(self, cutLineType: CutLineType) -> None: ...


class HandRail(ContinuousRail):


class HandRailType(ContinuousRailType):
    @property
    def Height(self) -> float: ...
    @Height.setter
    def Height(self, height: float) -> None: ...
    @property
    def SupportSpacing(self) -> float: ...
    @SupportSpacing.setter
    def SupportSpacing(self, supportSpacing: float) -> None: ...
    @property
    def SupportTypeId(self) -> ElementId: ...
    @SupportTypeId.setter
    def SupportTypeId(self, supportTypeId: ElementId) -> None: ...
    @property
    def SupportNumber(self) -> int: ...
    @SupportNumber.setter
    def SupportNumber(self, supportNumber: int) -> None: ...
    @property
    def SupportLayout(self) -> RailSupportsLayout: ...
    @SupportLayout.setter
    def SupportLayout(self, supportLayout: RailSupportsLayout) -> None: ...
    @property
    def SupportJustification(self) -> RailSupportJustification: ...
    @SupportJustification.setter
    def SupportJustification(self, supportJustification: RailSupportJustification) -> None: ...


class MultistoryStairs(Element):
    @property
    def ActualTreadDepth(self) -> float: ...
    @ActualTreadDepth.setter
    def ActualTreadDepth(self, actualTreadDepth: float) -> None: ...
    @property
    def StandardStairsId(self) -> ElementId: ...
    def Create(stairs: Stairs) -> MultistoryStairs: ...
    def IsAcceptableForMultistoryStairs(stairs: Stairs) -> bool: ...
    def ConnectLevels(self, levelIds: ISet) -> None: ...
    def DisconnectLevels(self, levelIds: ISet) -> None: ...
    def GetAllStairsIds(self) -> ISet: ...
    def GetStairsPlacementLevels(self, stairs: Stairs) -> ISet: ...
    def IsPinned(self, stairs: Stairs) -> bool: ...
    def GetAllConnectedLevels(self) -> ISet: ...
    def Unpin(self, levelId: ElementId) -> Stairs: ...
    def Pin(self, levelId: ElementId) -> Stairs: ...
    def GetStairsOnLevel(self, levelId: ElementId) -> Stairs: ...
    def CanConnectLevel(self, levelId: ElementId) -> bool: ...
    def CanDisconnectLevel(self, levelId: ElementId) -> bool: ...


class Stairs(Element):
    @property
    def ActualRiserHeight(self) -> float: ...
    @property
    def ActualTreadDepth(self) -> float: ...
    @ActualTreadDepth.setter
    def ActualTreadDepth(self, actualTreadDepth: float) -> None: ...
    @property
    def ActualRisersNumber(self) -> int: ...
    @property
    def DesiredRisersNumber(self) -> int: ...
    @DesiredRisersNumber.setter
    def DesiredRisersNumber(self, numberOfRisers: int) -> None: ...
    @property
    def BaseElevation(self) -> float: ...
    @property
    def TopElevation(self) -> float: ...
    @property
    def Height(self) -> float: ...
    @Height.setter
    def Height(self, stairsHeight: float) -> None: ...
    @property
    def ActualTreadsNumber(self) -> int: ...
    @property
    def NumberOfStories(self) -> int: ...
    @property
    def MultistoryStairsId(self) -> ElementId: ...
    def IsInEditMode(self) -> bool: ...
    def IsByComponent(document: Document, stairsId: ElementId) -> bool: ...
    def GetStairsRuns(self) -> ICollection: ...
    def GetStairsLandings(self) -> ICollection: ...
    def GetStairsSupports(self) -> ICollection: ...
    def GetAssociatedRailings(self) -> ICollection: ...


class StairsComponentConnection:
    @property
    def ElementId(self) -> ElementId: ...
    @property
    def PeerElementId(self) -> ElementId: ...
    @property
    def ConnectionType(self) -> StairsComponentConnectionEndType: ...
    @property
    def PeerConnectionType(self) -> StairsComponentConnectionEndType: ...
    @property
    def IsValidObject(self) -> bool: ...
    def Dispose(self) -> None: ...


class StairsLanding(Element):
    @property
    def Thickness(self) -> float: ...
    @property
    def BaseElevation(self) -> float: ...
    @BaseElevation.setter
    def BaseElevation(self, height: float) -> None: ...
    @property
    def IsAutomaticLanding(self) -> bool: ...
    def CreateAutomaticLanding(document: Document, firstRunId: ElementId, secondRunId: ElementId) -> List[ElementId]: ...
    def CanCreateAutomaticLanding(document: Document, firstRunId: ElementId, secondRunId: ElementId) -> bool: ...
    def CreateSketchedLanding(document: Document, stairsId: ElementId, curveLoop: CurveLoop, baseElevation: float) -> StairsLanding: ...
    def CreateSketchedLandingWithSlopeData(document: Document, stairsId: ElementId, curveLoop: List[SketchedStairsCurveData], baseElevation: float) -> StairsLanding: ...
    def GetFootprintBoundary(self) -> CurveLoop: ...
    def SetSketchedLandingBoundaryAndPath(self, document: Document, boundaryCurveLoop: CurveLoop, pathCurveLoop: CurveLoop) -> None: ...
    def GetStairs(self) -> Stairs: ...
    def GetAllSupports(self) -> List[ElementId]: ...
    def GetStairsPath(self) -> CurveLoop: ...
    def GetConnections(self) -> List[StairsComponentConnection]: ...


class StairsLandingType(ElementType):
    @property
    def IsMonolithic(self) -> bool: ...
    @property
    def Thickness(self) -> float: ...
    @Thickness.setter
    def Thickness(self, thickness: float) -> None: ...


class StairsPath(Element):
    @property
    def UpText(self) -> str: ...
    @UpText.setter
    def UpText(self, upText: str) -> None: ...
    @property
    def DownText(self) -> str: ...
    @DownText.setter
    def DownText(self, downText: str) -> None: ...
    @property
    def UpTextOffset(self) -> XYZ: ...
    @UpTextOffset.setter
    def UpTextOffset(self, upTextOffset: XYZ) -> None: ...
    @property
    def DownTextOffset(self) -> XYZ: ...
    @DownTextOffset.setter
    def DownTextOffset(self, downTextOffset: XYZ) -> None: ...
    @property
    def StairsPathOffset(self) -> float: ...
    @StairsPathOffset.setter
    def StairsPathOffset(self, stairsPathOffset: float) -> None: ...
    @property
    def StairsId(self) -> LinkElementId: ...
    @property
    def TextOrientation(self) -> StairsTextOrientation: ...
    @TextOrientation.setter
    def TextOrientation(self, textOrientation: StairsTextOrientation) -> None: ...
    @property
    def ShowUpText(self) -> bool: ...
    @ShowUpText.setter
    def ShowUpText(self, showUpText: bool) -> None: ...
    @property
    def ShowDownText(self) -> bool: ...
    @ShowDownText.setter
    def ShowDownText(self, showDownText: bool) -> None: ...
    def Create(document: Document, stairsId: LinkElementId, typeId: ElementId, planViewId: ElementId) -> StairsPath: ...
    def CreateOnMultistoryStairs(document: Document, multistoryStairsId: LinkElementId, typeId: ElementId) -> List[StairsPath]: ...
    def CanCreateOnMultistoryStairs(document: Document, multistoryStairsId: LinkElementId) -> bool: ...


class StairsPathType(ElementType):
    @property
    def DistanceToCutMark(self) -> float: ...
    @DistanceToCutMark.setter
    def DistanceToCutMark(self, distanceToCutMark: float) -> None: ...
    @property
    def StartExtension(self) -> float: ...
    @StartExtension.setter
    def StartExtension(self, startExtension: float) -> None: ...
    @property
    def ArrowheadTypeId(self) -> ElementId: ...
    @ArrowheadTypeId.setter
    def ArrowheadTypeId(self, arrowheadTypeId: ElementId) -> None: ...
    @property
    def LineShapeAtCorner(self) -> StairsPathLineShapeAtCorner: ...
    @LineShapeAtCorner.setter
    def LineShapeAtCorner(self, lineShapeAtCorner: StairsPathLineShapeAtCorner) -> None: ...
    @property
    def StairsPathDirection(self) -> StairsPathDirection: ...
    @property
    def StartSymbolTypeId(self) -> ElementId: ...
    @StartSymbolTypeId.setter
    def StartSymbolTypeId(self, startSymbolTypeId: ElementId) -> None: ...
    @property
    def EndAtRiser(self) -> bool: ...
    @EndAtRiser.setter
    def EndAtRiser(self, endAtRiser: bool) -> None: ...
    @property
    def DrawForEachRun(self) -> bool: ...
    @DrawForEachRun.setter
    def DrawForEachRun(self, drawForEachRun: bool) -> None: ...
    @property
    def ShowArrowheadToCutMark(self) -> bool: ...
    @ShowArrowheadToCutMark.setter
    def ShowArrowheadToCutMark(self, showArrowheadToCutMark: bool) -> None: ...
    @property
    def StartFromRiser(self) -> bool: ...
    @StartFromRiser.setter
    def StartFromRiser(self, startFromRiser: bool) -> None: ...
    @property
    def FullStepArrow(self) -> bool: ...
    @FullStepArrow.setter
    def FullStepArrow(self, fullStepArrow: bool) -> None: ...


class StairsRun(Element):
    @property
    def StairsRunStyle(self) -> StairsRunStyle: ...
    @property
    def Height(self) -> float: ...
    @property
    def BaseElevation(self) -> float: ...
    @BaseElevation.setter
    def BaseElevation(self, baseElevation: float) -> None: ...
    @property
    def TopElevation(self) -> float: ...
    @TopElevation.setter
    def TopElevation(self, topElevation: float) -> None: ...
    @property
    def ActualRunWidth(self) -> float: ...
    @ActualRunWidth.setter
    def ActualRunWidth(self, runWidth: float) -> None: ...
    @property
    def ActualRisersNumber(self) -> int: ...
    @property
    def ActualTreadsNumber(self) -> int: ...
    @property
    def ExtensionBelowRiserBase(self) -> float: ...
    @ExtensionBelowRiserBase.setter
    def ExtensionBelowRiserBase(self, extendBelowRiserBase: float) -> None: ...
    @property
    def ExtensionBelowTreadBase(self) -> float: ...
    @ExtensionBelowTreadBase.setter
    def ExtensionBelowTreadBase(self, extendBelowTreadBase: float) -> None: ...
    @property
    def BeginsWithRiser(self) -> bool: ...
    @BeginsWithRiser.setter
    def BeginsWithRiser(self, beingWithRiser: bool) -> None: ...
    @property
    def EndsWithRiser(self) -> bool: ...
    @EndsWithRiser.setter
    def EndsWithRiser(self, endWithRiser: bool) -> None: ...
    @property
    def LocationLineJustification(self) -> StairsRunJustification: ...
    @LocationLineJustification.setter
    def LocationLineJustification(self, pathJustification: StairsRunJustification) -> None: ...
    def SetLocationPathForStraightRun(stairsRun: StairsRun, locationPath: Line) -> bool: ...
    def SetLocationPathForSpiralRun(stairsRun: StairsRun, center: XYZ, radius: float, startAngle: float, includedAngle: float, clockwise: bool, justification: StairsRunJustification) -> bool: ...
    def GetNumberSystemReference(self, referenceOption: StairsNumberSystemReferenceOption) -> Reference: ...
    def GetConnections(self) -> List[StairsComponentConnection]: ...
    def GetLeftSupports(self) -> List[ElementId]: ...
    def GetRightSupports(self) -> List[ElementId]: ...
    def GetAllSupports(self) -> List[ElementId]: ...
    def GetStairs(self) -> Stairs: ...
    def GetStairsPath(self) -> CurveLoop: ...
    def GetFootprintBoundary(self) -> CurveLoop: ...
    def CreateSketchedRun(document: Document, stairsId: ElementId, baseElevation: float, boundaryCurves: List[Curve], riserCurves: List[Curve], stairsPath: List[Curve]) -> StairsRun: ...
    def CreateSketchedRunWithSlopeData(document: Document, stairsId: ElementId, baseElevation: float, boundaryCurves: List[SketchedStairsCurveData], riserCurves: List[Curve], stairsPath: List[Curve]) -> StairsRun: ...
    def CreateStraightRun(document: Document, stairsId: ElementId, locationPath: Line, justification: StairsRunJustification) -> StairsRun: ...
    def CreateSpiralRun(document: Document, stairsId: ElementId, center: XYZ, radius: float, startAngle: float, includedAngle: float, clockwise: bool, justification: StairsRunJustification) -> StairsRun: ...


class StairsRunType(ElementType):
    @property
    def IsMonolithic(self) -> bool: ...
    @property
    def HasTreads(self) -> bool: ...
    @HasTreads.setter
    def HasTreads(self, hasTreads: bool) -> None: ...
    @property
    def HasRisers(self) -> bool: ...
    @HasRisers.setter
    def HasRisers(self, hasRisers: bool) -> None: ...
    @property
    def StructuralDepth(self) -> float: ...
    @StructuralDepth.setter
    def StructuralDepth(self, structuralDepth: float) -> None: ...
    @property
    def TotalDepth(self) -> float: ...
    @property
    def UndersideSurfaceStyle(self) -> StairsUndersideSurfaceStyle: ...
    @UndersideSurfaceStyle.setter
    def UndersideSurfaceStyle(self, undersideSurfaceStyle: StairsUndersideSurfaceStyle) -> None: ...
    @property
    def MaterialId(self) -> ElementId: ...
    @MaterialId.setter
    def MaterialId(self, materialId: ElementId) -> None: ...
    @property
    def TreadThickness(self) -> float: ...
    @TreadThickness.setter
    def TreadThickness(self, thickness: float) -> None: ...
    @property
    def NosingLength(self) -> float: ...
    @NosingLength.setter
    def NosingLength(self, length: float) -> None: ...
    @property
    def NosingProfile(self) -> ElementId: ...
    @NosingProfile.setter
    def NosingProfile(self, profile: ElementId) -> None: ...
    @property
    def TreadProfile(self) -> ElementId: ...
    @TreadProfile.setter
    def TreadProfile(self, profile: ElementId) -> None: ...
    @property
    def TreadNosingPosition(self) -> TreadNosingPosition: ...
    @TreadNosingPosition.setter
    def TreadNosingPosition(self, nosingPosition: TreadNosingPosition) -> None: ...
    @property
    def IsSlanted(self) -> bool: ...
    @IsSlanted.setter
    def IsSlanted(self, slanted: bool) -> None: ...
    @property
    def RiserThickness(self) -> float: ...
    @RiserThickness.setter
    def RiserThickness(self, length: float) -> None: ...
    @property
    def RiserProfile(self) -> ElementId: ...
    @RiserProfile.setter
    def RiserProfile(self, profile: ElementId) -> None: ...
    @property
    def RiserToTreadConnect(self) -> RiserToTreadConnectionOption: ...
    @RiserToTreadConnect.setter
    def RiserToTreadConnect(self, connect: RiserToTreadConnectionOption) -> None: ...


class StairsType(ElementType):
    @property
    def MaxRiserHeight(self) -> float: ...
    @MaxRiserHeight.setter
    def MaxRiserHeight(self, MaxRiserHeight: float) -> None: ...
    @property
    def MinTreadDepth(self) -> float: ...
    @MinTreadDepth.setter
    def MinTreadDepth(self, minTreadDepth: float) -> None: ...
    @property
    def MinRunWidth(self) -> float: ...
    @MinRunWidth.setter
    def MinRunWidth(self, MinRunWidth: float) -> None: ...
    @property
    def NotchExtension(self) -> float: ...
    @NotchExtension.setter
    def NotchExtension(self, NotchExtension: float) -> None: ...
    @property
    def NotchThickness(self) -> float: ...
    @NotchThickness.setter
    def NotchThickness(self, NotchThickness: float) -> None: ...
    @property
    def NotchHorizontalGap(self) -> float: ...
    @NotchHorizontalGap.setter
    def NotchHorizontalGap(self, NotchHorizontalGap: float) -> None: ...
    @property
    def NotchVerticalGap(self) -> float: ...
    @NotchVerticalGap.setter
    def NotchVerticalGap(self, NotchVerticalGap: float) -> None: ...
    @property
    def RunType(self) -> ElementId: ...
    @RunType.setter
    def RunType(self, RunType: ElementId) -> None: ...
    @property
    def LandingType(self) -> ElementId: ...
    @LandingType.setter
    def LandingType(self, LandingType: ElementId) -> None: ...
    @property
    def EndConnectionType(self) -> StairsEndConnectionType: ...
    @EndConnectionType.setter
    def EndConnectionType(self, EndConnectionType: StairsEndConnectionType) -> None: ...
    @property
    def ConstructionMethod(self) -> StairsConstructionMethod: ...
    @property
    def LeftSideSupportType(self) -> ElementId: ...
    @LeftSideSupportType.setter
    def LeftSideSupportType(self, leftSideStringerTypeId: ElementId) -> None: ...
    @property
    def RightSideSupportType(self) -> ElementId: ...
    @RightSideSupportType.setter
    def RightSideSupportType(self, rightSideStringerTypeId: ElementId) -> None: ...
    @property
    def LeftLateralOffset(self) -> float: ...
    @LeftLateralOffset.setter
    def LeftLateralOffset(self, offset: float) -> None: ...
    @property
    def RightLateralOffset(self) -> float: ...
    @RightLateralOffset.setter
    def RightLateralOffset(self, offset: float) -> None: ...
    @property
    def MiddleSupportsNumber(self) -> int: ...
    @MiddleSupportsNumber.setter
    def MiddleSupportsNumber(self, supportsNumber: int) -> None: ...
    @property
    def MiddleSupportType(self) -> ElementId: ...
    @MiddleSupportType.setter
    def MiddleSupportType(self, supportType: ElementId) -> None: ...
    @property
    def HasMiddleSupports(self) -> bool: ...
    @HasMiddleSupports.setter
    def HasMiddleSupports(self, hasSupports: bool) -> None: ...


class TopRail(ContinuousRail):


class TopRailType(ContinuousRailType):


class SiteSubRegion:
    @property
    def TopographySurface(self) -> TopographySurface: ...
    @property
    def HostId(self) -> ElementId: ...
    @property
    def IsValidObject(self) -> bool: ...
    @overload
    def Create(document: Document, curveLoops: List[CurveLoop], hostTopoSurfaceId: ElementId) -> SiteSubRegion: ...
    @overload
    def Create(document: Document, curveLoops: List[CurveLoop]) -> SiteSubRegion: ...
    def IsValidBoundary(curveLoops: List[CurveLoop]) -> bool: ...
    def GetBoundary(self) -> List[CurveLoop]: ...
    def SetBoundary(self, curveLoops: List[CurveLoop]) -> None: ...
    def Dispose(self) -> None: ...


class Railing(Element):
    @property
    def HostId(self) -> ElementId: ...
    @HostId.setter
    def HostId(self, hostId: ElementId) -> None: ...
    @property
    def HasHost(self) -> bool: ...
    @property
    def Flipped(self) -> bool: ...
    @property
    def TopRail(self) -> ElementId: ...
    @property
    def IsDefault(self) -> bool: ...
    @property
    def CanReset(self) -> bool: ...
    @overload
    def Create(document: Document, multistoryStairsId: ElementId, levelId: ElementId, railingTypeId: ElementId, placePosition: RailingPlacementPosition) -> ISet: ...
    @overload
    def Create(document: Document, curveLoop: CurveLoop, railingTypeId: ElementId, baseLevelId: ElementId) -> Railing: ...
    @overload
    def Create(document: Document, stairsOrRampId: ElementId, railingTypeId: ElementId, placePosition: RailingPlacementPosition) -> ICollection: ...
    def GetPath(self) -> List[Curve]: ...
    def SetPath(self, curveLoop: CurveLoop) -> None: ...
    def RailingCanBeHostedByElement(self, hostId: ElementId) -> bool: ...
    def GetHandRails(self) -> List[ElementId]: ...
    def Reset(self) -> None: ...
    def Flip(self) -> None: ...
    def RemoveHost(self) -> None: ...
    def GetMultistoryStairsPlacementLevels(self) -> ISet: ...
    def SetMultistoryStairsPlacementLevels(self, levelIds: ISet) -> None: ...
    def GetSubelementOnLevel(self, levelId: ElementId) -> Subelement: ...
    def ResetSupportPosition(self) -> None: ...
    def IsValidHostForNewRailing(document: Document, elementId: ElementId) -> bool: ...
    def IsValidPathForRailing(curveLoop: CurveLoop) -> bool: ...


class RailingType(ElementType):
    @property
    def BalusterPlacement(self) -> BalusterPlacement: ...
    @property
    def RailStructure(self) -> NonContinuousRailStructure: ...
    @property
    def PrimaryHandRailPosition(self) -> HandRailPosition: ...
    @PrimaryHandRailPosition.setter
    def PrimaryHandRailPosition(self, primaryHandRailPosition: HandRailPosition) -> None: ...
    @property
    def SecondaryHandRailPosition(self) -> HandRailPosition: ...
    @SecondaryHandRailPosition.setter
    def SecondaryHandRailPosition(self, secondaryHandRailPosition: HandRailPosition) -> None: ...
    @property
    def TopRailHeight(self) -> float: ...
    @TopRailHeight.setter
    def TopRailHeight(self, height: float) -> None: ...
    @property
    def TopRailType(self) -> ElementId: ...
    @TopRailType.setter
    def TopRailType(self, topRailType: ElementId) -> None: ...
    @property
    def PrimaryHandrailType(self) -> ElementId: ...
    @PrimaryHandrailType.setter
    def PrimaryHandrailType(self, handRailTypeId: ElementId) -> None: ...
    @property
    def SecondaryHandrailType(self) -> ElementId: ...
    @SecondaryHandrailType.setter
    def SecondaryHandrailType(self, handRailTypeId: ElementId) -> None: ...
    @property
    def PrimaryHandrailLateralOffset(self) -> float: ...
    @property
    def SecondaryHandrailLateralOffset(self) -> float: ...
    @property
    def PrimaryHandrailHeight(self) -> float: ...
    @property
    def SecondaryHandrailHeight(self) -> float: ...


class StairsTextOrientation:
    Horizontal = 0
    Vertical = 1


class StairsPathLineShapeAtCorner:
    Straight = 0
    Curved = 1


class CutMarkSymbol:
    #None = 0
    Zigzag = 1
    Curve = 2


class CutLineType:
    SingleLine = 0
    DoubleLine = 1


class StairsNumberSystemReferenceOption:
    Center = 0
    Left = 1
    Right = 2
    LeftQuarter = 3
    RightQuarter = 4


class StairsPathDirection:
    AlwaysUp = 0
    AutomaticUpDown = 1


class StairsEndConnectionType:
    StraightCut = 0
    Notch = 1


class StairsEndNotchOption:
    FullRunWidth = 0
    Custom = 1


class StairsRunJustification:
    Left = 0
    Center = 1
    Right = 2
    LeftExterior = 3
    RightExterior = 4


class StairsWinderStyle:
    Balanced = 0
    SinglePoint = 2


class StairsRunStyle:
    Winder = 1
    Sketched = 2
    Straight = 3
    Spiral = 4


class StairsUndersideSurfaceStyle:
    Stepped = 0
    Smooth = 1


class StairsSupportTopsideSurfaceType:
    Closed = 0
    Open = 1


class StairsComponentConnectionEndType:
    ET_Landing = 0
    ET_RunStart = 1
    ET_RunEnd = 2


class WinderPathResult:
    Success = 0
    NumberOutOfRange = 1
    Unbound = 2
    Noncontinuous = 3
    NotOpenLoop = 4
    TooShort = 5
    ColinearOrOverlap = 6
    SelfIntersect = 7
    InvalidCurveType = 8
    NotSupported = 9


class StairsConstructionMethod:
    Assembled = 0
    CastInPlace = 1
    Precast = 2


class TreadNosingPosition:
    FrontOnly = 0
    FrontAndLeft = 1
    FrontAndRight = 2
    FrontLeftAndRight = 3


class RiserToTreadConnectionOption:
    RiserBehindTread = 0
    TreadUnderRiser = 1
    JoinAll = 2


class SketchedCurveSlopeOption:
    Auto = 0
    Flat = 1
    Sloped = 2


class TopographyEditScope(EditScope):
    def __init__(self, document: Document, transactionName: str): ...
    @property
    def IsPermitted(self) -> bool: ...
    def Start(self, topoSurfaceId: ElementId) -> ElementId: ...


class TopographyLinkType(ElementType):
    def Reload(self) -> LinkLoadResult: ...



class PerformanceCounterPermission(ResourcePermissionBase,IPermission,ISecurityEncodable,IStackWalk,IUnrestrictedPermission):
 """
 Allows control of code access permissions for System.Diagnostics.PerformanceCounter.

 

 PerformanceCounterPermission()

 PerformanceCounterPermission(state: PermissionState)

 PerformanceCounterPermission(permissionAccess: PerformanceCounterPermissionAccess,machineName: str,categoryName: str)

 PerformanceCounterPermission(permissionAccessEntries: Array[PerformanceCounterPermissionEntry])
 """
 def AddPermissionAccess(self,*args):
  """
  AddPermissionAccess(self: ResourcePermissionBase,entry: ResourcePermissionBaseEntry)

   Adds a permission entry to the permission.

  

   entry: The System.Security.Permissions.ResourcePermissionBaseEntry to add.
  """
  pass
 def Clear(self,*args):
  """
  Clear(self: ResourcePermissionBase)

   Clears the permission of the added permission entries.
  """
  pass
 def GetPermissionEntries(self,*args):
  """
  GetPermissionEntries(self: ResourcePermissionBase) -> Array[ResourcePermissionBaseEntry]

  

   Returns an array of the System.Security.Permissions.ResourcePermissionBaseEntry objects added to 

    this permission.

  

   Returns: An array of System.Security.Permissions.ResourcePermissionBaseEntry objects that were added to 

    this permission.
  """
  pass
 def RemovePermissionAccess(self,*args):
  """
  RemovePermissionAccess(self: ResourcePermissionBase,entry: ResourcePermissionBaseEntry)

   Removes a permission entry from the permission.

  

   entry: The System.Security.Permissions.ResourcePermissionBaseEntry to remove.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,state: PermissionState)

  __new__(cls: type,permissionAccess: PerformanceCounterPermissionAccess,machineName: str,categoryName: str)

  __new__(cls: type,permissionAccessEntries: Array[PerformanceCounterPermissionEntry])
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 PermissionAccessType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets an enumeration value that describes the types of access that you are giving the resource.



"""

 PermissionEntries=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the collection of permission entries for this permissions request.



Get: PermissionEntries(self: PerformanceCounterPermission) -> PerformanceCounterPermissionEntryCollection



"""

 TagNames=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets an array of strings that identify the resource you are protecting.



"""


